# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class StandaloneInvestmentTransactionSubtype(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_fee': 'str',
        'assignment': 'str',
        'buy': 'str',
        'buy_to_cover': 'str',
        'contribution': 'str',
        'deposit': 'str',
        'distribution': 'str',
        'dividend': 'str',
        'dividend_reinvestment': 'str',
        'exercise': 'str',
        'expire': 'str',
        'fund_fee': 'str',
        'interest': 'str',
        'interest_receivable': 'str',
        'interest_reinvestment': 'str',
        'legal_fee': 'str',
        'loan_payment': 'str',
        'long_term_capital_gain': 'str',
        'long_term_capital_gain_reinvestment': 'str',
        'management_fee': 'str',
        'margin_expense': 'str',
        'merger': 'str',
        'miscellaneous_fee': 'str',
        'non_qualified_dividend': 'str',
        'non_resident_tax': 'str',
        'pending_credit': 'str',
        'pending_debit': 'str',
        'qualified_dividend': 'str',
        'rebalance': 'str',
        'return_of_principal': 'str',
        'sell': 'str',
        'sell_short': 'str',
        'short_term_capital_gain': 'str',
        'short_term_capital_gain_reinvestment': 'str',
        'spin_off': 'str',
        'split': 'str',
        'stock_distribution': 'str',
        'tax': 'str',
        'tax_withheld': 'str',
        'transfer': 'str',
        'transfer_fee': 'str',
        'trust_fee': 'str',
        'unqualified_gain': 'str',
        'withdrawal': 'str'
    }

    attribute_map = {
        'account_fee': 'account fee',
        'assignment': 'assignment',
        'buy': 'buy',
        'buy_to_cover': 'buy to cover',
        'contribution': 'contribution',
        'deposit': 'deposit',
        'distribution': 'distribution',
        'dividend': 'dividend',
        'dividend_reinvestment': 'dividend reinvestment',
        'exercise': 'exercise',
        'expire': 'expire',
        'fund_fee': 'fund fee',
        'interest': 'interest',
        'interest_receivable': 'interest receivable',
        'interest_reinvestment': 'interest reinvestment',
        'legal_fee': 'legal fee',
        'loan_payment': 'loan payment',
        'long_term_capital_gain': 'long-term capital gain',
        'long_term_capital_gain_reinvestment': 'long-term capital gain reinvestment',
        'management_fee': 'management fee',
        'margin_expense': 'margin expense',
        'merger': 'merger',
        'miscellaneous_fee': 'miscellaneous fee',
        'non_qualified_dividend': 'non-qualified dividend',
        'non_resident_tax': 'non-resident tax',
        'pending_credit': 'pending credit',
        'pending_debit': 'pending debit',
        'qualified_dividend': 'qualified dividend',
        'rebalance': 'rebalance',
        'return_of_principal': 'return of principal',
        'sell': 'sell',
        'sell_short': 'sell short',
        'short_term_capital_gain': 'short-term capital gain',
        'short_term_capital_gain_reinvestment': 'short-term capital gain reinvestment',
        'spin_off': 'spin off',
        'split': 'split',
        'stock_distribution': 'stock distribution',
        'tax': 'tax',
        'tax_withheld': 'tax withheld',
        'transfer': 'transfer',
        'transfer_fee': 'transfer fee',
        'trust_fee': 'trust fee',
        'unqualified_gain': 'unqualified gain',
        'withdrawal': 'withdrawal'
    }

    def __init__(self, account_fee=None, assignment=None, buy=None, buy_to_cover=None, contribution=None, deposit=None, distribution=None, dividend=None, dividend_reinvestment=None, exercise=None, expire=None, fund_fee=None, interest=None, interest_receivable=None, interest_reinvestment=None, legal_fee=None, loan_payment=None, long_term_capital_gain=None, long_term_capital_gain_reinvestment=None, management_fee=None, margin_expense=None, merger=None, miscellaneous_fee=None, non_qualified_dividend=None, non_resident_tax=None, pending_credit=None, pending_debit=None, qualified_dividend=None, rebalance=None, return_of_principal=None, sell=None, sell_short=None, short_term_capital_gain=None, short_term_capital_gain_reinvestment=None, spin_off=None, split=None, stock_distribution=None, tax=None, tax_withheld=None, transfer=None, transfer_fee=None, trust_fee=None, unqualified_gain=None, withdrawal=None, local_vars_configuration=None):  # noqa: E501
        """StandaloneInvestmentTransactionSubtype - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_fee = None
        self._assignment = None
        self._buy = None
        self._buy_to_cover = None
        self._contribution = None
        self._deposit = None
        self._distribution = None
        self._dividend = None
        self._dividend_reinvestment = None
        self._exercise = None
        self._expire = None
        self._fund_fee = None
        self._interest = None
        self._interest_receivable = None
        self._interest_reinvestment = None
        self._legal_fee = None
        self._loan_payment = None
        self._long_term_capital_gain = None
        self._long_term_capital_gain_reinvestment = None
        self._management_fee = None
        self._margin_expense = None
        self._merger = None
        self._miscellaneous_fee = None
        self._non_qualified_dividend = None
        self._non_resident_tax = None
        self._pending_credit = None
        self._pending_debit = None
        self._qualified_dividend = None
        self._rebalance = None
        self._return_of_principal = None
        self._sell = None
        self._sell_short = None
        self._short_term_capital_gain = None
        self._short_term_capital_gain_reinvestment = None
        self._spin_off = None
        self._split = None
        self._stock_distribution = None
        self._tax = None
        self._tax_withheld = None
        self._transfer = None
        self._transfer_fee = None
        self._trust_fee = None
        self._unqualified_gain = None
        self._withdrawal = None
        self.discriminator = None

        if account_fee is not None:
            self.account_fee = account_fee
        if assignment is not None:
            self.assignment = assignment
        if buy is not None:
            self.buy = buy
        if buy_to_cover is not None:
            self.buy_to_cover = buy_to_cover
        if contribution is not None:
            self.contribution = contribution
        if deposit is not None:
            self.deposit = deposit
        if distribution is not None:
            self.distribution = distribution
        if dividend is not None:
            self.dividend = dividend
        if dividend_reinvestment is not None:
            self.dividend_reinvestment = dividend_reinvestment
        if exercise is not None:
            self.exercise = exercise
        if expire is not None:
            self.expire = expire
        if fund_fee is not None:
            self.fund_fee = fund_fee
        if interest is not None:
            self.interest = interest
        if interest_receivable is not None:
            self.interest_receivable = interest_receivable
        if interest_reinvestment is not None:
            self.interest_reinvestment = interest_reinvestment
        if legal_fee is not None:
            self.legal_fee = legal_fee
        if loan_payment is not None:
            self.loan_payment = loan_payment
        if long_term_capital_gain is not None:
            self.long_term_capital_gain = long_term_capital_gain
        if long_term_capital_gain_reinvestment is not None:
            self.long_term_capital_gain_reinvestment = long_term_capital_gain_reinvestment
        if management_fee is not None:
            self.management_fee = management_fee
        if margin_expense is not None:
            self.margin_expense = margin_expense
        if merger is not None:
            self.merger = merger
        if miscellaneous_fee is not None:
            self.miscellaneous_fee = miscellaneous_fee
        if non_qualified_dividend is not None:
            self.non_qualified_dividend = non_qualified_dividend
        if non_resident_tax is not None:
            self.non_resident_tax = non_resident_tax
        if pending_credit is not None:
            self.pending_credit = pending_credit
        if pending_debit is not None:
            self.pending_debit = pending_debit
        if qualified_dividend is not None:
            self.qualified_dividend = qualified_dividend
        if rebalance is not None:
            self.rebalance = rebalance
        if return_of_principal is not None:
            self.return_of_principal = return_of_principal
        if sell is not None:
            self.sell = sell
        if sell_short is not None:
            self.sell_short = sell_short
        if short_term_capital_gain is not None:
            self.short_term_capital_gain = short_term_capital_gain
        if short_term_capital_gain_reinvestment is not None:
            self.short_term_capital_gain_reinvestment = short_term_capital_gain_reinvestment
        if spin_off is not None:
            self.spin_off = spin_off
        if split is not None:
            self.split = split
        if stock_distribution is not None:
            self.stock_distribution = stock_distribution
        if tax is not None:
            self.tax = tax
        if tax_withheld is not None:
            self.tax_withheld = tax_withheld
        if transfer is not None:
            self.transfer = transfer
        if transfer_fee is not None:
            self.transfer_fee = transfer_fee
        if trust_fee is not None:
            self.trust_fee = trust_fee
        if unqualified_gain is not None:
            self.unqualified_gain = unqualified_gain
        if withdrawal is not None:
            self.withdrawal = withdrawal

    @property
    def account_fee(self):
        """Gets the account_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Fees paid for account maintenance  # noqa: E501

        :return: The account_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._account_fee

    @account_fee.setter
    def account_fee(self, account_fee):
        """Sets the account_fee of this StandaloneInvestmentTransactionSubtype.

        Fees paid for account maintenance  # noqa: E501

        :param account_fee: The account_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type account_fee: str
        """

        self._account_fee = account_fee

    @property
    def assignment(self):
        """Gets the assignment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Assignment of short option holding  # noqa: E501

        :return: The assignment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._assignment

    @assignment.setter
    def assignment(self, assignment):
        """Sets the assignment of this StandaloneInvestmentTransactionSubtype.

        Assignment of short option holding  # noqa: E501

        :param assignment: The assignment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type assignment: str
        """

        self._assignment = assignment

    @property
    def buy(self):
        """Gets the buy of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Purchase to open or increase a position  # noqa: E501

        :return: The buy of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._buy

    @buy.setter
    def buy(self, buy):
        """Sets the buy of this StandaloneInvestmentTransactionSubtype.

        Purchase to open or increase a position  # noqa: E501

        :param buy: The buy of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type buy: str
        """

        self._buy = buy

    @property
    def buy_to_cover(self):
        """Gets the buy_to_cover of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Purchase to close a short position  # noqa: E501

        :return: The buy_to_cover of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._buy_to_cover

    @buy_to_cover.setter
    def buy_to_cover(self, buy_to_cover):
        """Sets the buy_to_cover of this StandaloneInvestmentTransactionSubtype.

        Purchase to close a short position  # noqa: E501

        :param buy_to_cover: The buy_to_cover of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type buy_to_cover: str
        """

        self._buy_to_cover = buy_to_cover

    @property
    def contribution(self):
        """Gets the contribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of assets into a tax-advantaged account  # noqa: E501

        :return: The contribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._contribution

    @contribution.setter
    def contribution(self, contribution):
        """Sets the contribution of this StandaloneInvestmentTransactionSubtype.

        Inflow of assets into a tax-advantaged account  # noqa: E501

        :param contribution: The contribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type contribution: str
        """

        self._contribution = contribution

    @property
    def deposit(self):
        """Gets the deposit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of cash into an account  # noqa: E501

        :return: The deposit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._deposit

    @deposit.setter
    def deposit(self, deposit):
        """Sets the deposit of this StandaloneInvestmentTransactionSubtype.

        Inflow of cash into an account  # noqa: E501

        :param deposit: The deposit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type deposit: str
        """

        self._deposit = deposit

    @property
    def distribution(self):
        """Gets the distribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Outflow of assets from a tax-advantaged account  # noqa: E501

        :return: The distribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._distribution

    @distribution.setter
    def distribution(self, distribution):
        """Sets the distribution of this StandaloneInvestmentTransactionSubtype.

        Outflow of assets from a tax-advantaged account  # noqa: E501

        :param distribution: The distribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type distribution: str
        """

        self._distribution = distribution

    @property
    def dividend(self):
        """Gets the dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of cash from a dividend  # noqa: E501

        :return: The dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._dividend

    @dividend.setter
    def dividend(self, dividend):
        """Sets the dividend of this StandaloneInvestmentTransactionSubtype.

        Inflow of cash from a dividend  # noqa: E501

        :param dividend: The dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type dividend: str
        """

        self._dividend = dividend

    @property
    def dividend_reinvestment(self):
        """Gets the dividend_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Purchase using proceeds from a cash dividend  # noqa: E501

        :return: The dividend_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._dividend_reinvestment

    @dividend_reinvestment.setter
    def dividend_reinvestment(self, dividend_reinvestment):
        """Sets the dividend_reinvestment of this StandaloneInvestmentTransactionSubtype.

        Purchase using proceeds from a cash dividend  # noqa: E501

        :param dividend_reinvestment: The dividend_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type dividend_reinvestment: str
        """

        self._dividend_reinvestment = dividend_reinvestment

    @property
    def exercise(self):
        """Gets the exercise of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Exercise of an option or warrant contract  # noqa: E501

        :return: The exercise of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._exercise

    @exercise.setter
    def exercise(self, exercise):
        """Sets the exercise of this StandaloneInvestmentTransactionSubtype.

        Exercise of an option or warrant contract  # noqa: E501

        :param exercise: The exercise of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type exercise: str
        """

        self._exercise = exercise

    @property
    def expire(self):
        """Gets the expire of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Expiration of an option or warrant contract   # noqa: E501

        :return: The expire of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._expire

    @expire.setter
    def expire(self, expire):
        """Sets the expire of this StandaloneInvestmentTransactionSubtype.

        Expiration of an option or warrant contract   # noqa: E501

        :param expire: The expire of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type expire: str
        """

        self._expire = expire

    @property
    def fund_fee(self):
        """Gets the fund_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Fees paid for administration of a mutual fund or other pooled investment vehicle  # noqa: E501

        :return: The fund_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._fund_fee

    @fund_fee.setter
    def fund_fee(self, fund_fee):
        """Sets the fund_fee of this StandaloneInvestmentTransactionSubtype.

        Fees paid for administration of a mutual fund or other pooled investment vehicle  # noqa: E501

        :param fund_fee: The fund_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type fund_fee: str
        """

        self._fund_fee = fund_fee

    @property
    def interest(self):
        """Gets the interest of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of cash from interest  # noqa: E501

        :return: The interest of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._interest

    @interest.setter
    def interest(self, interest):
        """Sets the interest of this StandaloneInvestmentTransactionSubtype.

        Inflow of cash from interest  # noqa: E501

        :param interest: The interest of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type interest: str
        """

        self._interest = interest

    @property
    def interest_receivable(self):
        """Gets the interest_receivable of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of cash from interest receivable  # noqa: E501

        :return: The interest_receivable of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._interest_receivable

    @interest_receivable.setter
    def interest_receivable(self, interest_receivable):
        """Sets the interest_receivable of this StandaloneInvestmentTransactionSubtype.

        Inflow of cash from interest receivable  # noqa: E501

        :param interest_receivable: The interest_receivable of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type interest_receivable: str
        """

        self._interest_receivable = interest_receivable

    @property
    def interest_reinvestment(self):
        """Gets the interest_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Purchase using proceeds from a cash interest payment  # noqa: E501

        :return: The interest_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._interest_reinvestment

    @interest_reinvestment.setter
    def interest_reinvestment(self, interest_reinvestment):
        """Sets the interest_reinvestment of this StandaloneInvestmentTransactionSubtype.

        Purchase using proceeds from a cash interest payment  # noqa: E501

        :param interest_reinvestment: The interest_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type interest_reinvestment: str
        """

        self._interest_reinvestment = interest_reinvestment

    @property
    def legal_fee(self):
        """Gets the legal_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Fees paid for legal charges or services  # noqa: E501

        :return: The legal_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._legal_fee

    @legal_fee.setter
    def legal_fee(self, legal_fee):
        """Sets the legal_fee of this StandaloneInvestmentTransactionSubtype.

        Fees paid for legal charges or services  # noqa: E501

        :param legal_fee: The legal_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type legal_fee: str
        """

        self._legal_fee = legal_fee

    @property
    def loan_payment(self):
        """Gets the loan_payment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of cash related to payment on a loan  # noqa: E501

        :return: The loan_payment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._loan_payment

    @loan_payment.setter
    def loan_payment(self, loan_payment):
        """Sets the loan_payment of this StandaloneInvestmentTransactionSubtype.

        Inflow of cash related to payment on a loan  # noqa: E501

        :param loan_payment: The loan_payment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type loan_payment: str
        """

        self._loan_payment = loan_payment

    @property
    def long_term_capital_gain(self):
        """Gets the long_term_capital_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Long-term capital gain received as cash  # noqa: E501

        :return: The long_term_capital_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._long_term_capital_gain

    @long_term_capital_gain.setter
    def long_term_capital_gain(self, long_term_capital_gain):
        """Sets the long_term_capital_gain of this StandaloneInvestmentTransactionSubtype.

        Long-term capital gain received as cash  # noqa: E501

        :param long_term_capital_gain: The long_term_capital_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type long_term_capital_gain: str
        """

        self._long_term_capital_gain = long_term_capital_gain

    @property
    def long_term_capital_gain_reinvestment(self):
        """Gets the long_term_capital_gain_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Purchase using long-term capital gain cash proceeds  # noqa: E501

        :return: The long_term_capital_gain_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._long_term_capital_gain_reinvestment

    @long_term_capital_gain_reinvestment.setter
    def long_term_capital_gain_reinvestment(self, long_term_capital_gain_reinvestment):
        """Sets the long_term_capital_gain_reinvestment of this StandaloneInvestmentTransactionSubtype.

        Purchase using long-term capital gain cash proceeds  # noqa: E501

        :param long_term_capital_gain_reinvestment: The long_term_capital_gain_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type long_term_capital_gain_reinvestment: str
        """

        self._long_term_capital_gain_reinvestment = long_term_capital_gain_reinvestment

    @property
    def management_fee(self):
        """Gets the management_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Fees paid for investment management of a mutual fund or other pooled investment vehicle  # noqa: E501

        :return: The management_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._management_fee

    @management_fee.setter
    def management_fee(self, management_fee):
        """Sets the management_fee of this StandaloneInvestmentTransactionSubtype.

        Fees paid for investment management of a mutual fund or other pooled investment vehicle  # noqa: E501

        :param management_fee: The management_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type management_fee: str
        """

        self._management_fee = management_fee

    @property
    def margin_expense(self):
        """Gets the margin_expense of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Fees paid for maintaining margin debt  # noqa: E501

        :return: The margin_expense of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._margin_expense

    @margin_expense.setter
    def margin_expense(self, margin_expense):
        """Sets the margin_expense of this StandaloneInvestmentTransactionSubtype.

        Fees paid for maintaining margin debt  # noqa: E501

        :param margin_expense: The margin_expense of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type margin_expense: str
        """

        self._margin_expense = margin_expense

    @property
    def merger(self):
        """Gets the merger of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Stock exchanged at a pre-defined ratio as part of a merger between companies  # noqa: E501

        :return: The merger of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._merger

    @merger.setter
    def merger(self, merger):
        """Sets the merger of this StandaloneInvestmentTransactionSubtype.

        Stock exchanged at a pre-defined ratio as part of a merger between companies  # noqa: E501

        :param merger: The merger of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type merger: str
        """

        self._merger = merger

    @property
    def miscellaneous_fee(self):
        """Gets the miscellaneous_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Fee associated with various account or holding actions  # noqa: E501

        :return: The miscellaneous_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._miscellaneous_fee

    @miscellaneous_fee.setter
    def miscellaneous_fee(self, miscellaneous_fee):
        """Sets the miscellaneous_fee of this StandaloneInvestmentTransactionSubtype.

        Fee associated with various account or holding actions  # noqa: E501

        :param miscellaneous_fee: The miscellaneous_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type miscellaneous_fee: str
        """

        self._miscellaneous_fee = miscellaneous_fee

    @property
    def non_qualified_dividend(self):
        """Gets the non_qualified_dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of cash from a non-qualified dividend  # noqa: E501

        :return: The non_qualified_dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._non_qualified_dividend

    @non_qualified_dividend.setter
    def non_qualified_dividend(self, non_qualified_dividend):
        """Sets the non_qualified_dividend of this StandaloneInvestmentTransactionSubtype.

        Inflow of cash from a non-qualified dividend  # noqa: E501

        :param non_qualified_dividend: The non_qualified_dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type non_qualified_dividend: str
        """

        self._non_qualified_dividend = non_qualified_dividend

    @property
    def non_resident_tax(self):
        """Gets the non_resident_tax of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Taxes paid on behalf of the investor for non-residency in investment jurisdiction  # noqa: E501

        :return: The non_resident_tax of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._non_resident_tax

    @non_resident_tax.setter
    def non_resident_tax(self, non_resident_tax):
        """Sets the non_resident_tax of this StandaloneInvestmentTransactionSubtype.

        Taxes paid on behalf of the investor for non-residency in investment jurisdiction  # noqa: E501

        :param non_resident_tax: The non_resident_tax of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type non_resident_tax: str
        """

        self._non_resident_tax = non_resident_tax

    @property
    def pending_credit(self):
        """Gets the pending_credit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Pending inflow of cash  # noqa: E501

        :return: The pending_credit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._pending_credit

    @pending_credit.setter
    def pending_credit(self, pending_credit):
        """Sets the pending_credit of this StandaloneInvestmentTransactionSubtype.

        Pending inflow of cash  # noqa: E501

        :param pending_credit: The pending_credit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type pending_credit: str
        """

        self._pending_credit = pending_credit

    @property
    def pending_debit(self):
        """Gets the pending_debit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Pending outflow of cash  # noqa: E501

        :return: The pending_debit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._pending_debit

    @pending_debit.setter
    def pending_debit(self, pending_debit):
        """Sets the pending_debit of this StandaloneInvestmentTransactionSubtype.

        Pending outflow of cash  # noqa: E501

        :param pending_debit: The pending_debit of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type pending_debit: str
        """

        self._pending_debit = pending_debit

    @property
    def qualified_dividend(self):
        """Gets the qualified_dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of cash from a qualified dividend  # noqa: E501

        :return: The qualified_dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._qualified_dividend

    @qualified_dividend.setter
    def qualified_dividend(self, qualified_dividend):
        """Sets the qualified_dividend of this StandaloneInvestmentTransactionSubtype.

        Inflow of cash from a qualified dividend  # noqa: E501

        :param qualified_dividend: The qualified_dividend of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type qualified_dividend: str
        """

        self._qualified_dividend = qualified_dividend

    @property
    def rebalance(self):
        """Gets the rebalance of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Rebalancing transaction (buy or sell) with no net impact to value in the account  # noqa: E501

        :return: The rebalance of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._rebalance

    @rebalance.setter
    def rebalance(self, rebalance):
        """Sets the rebalance of this StandaloneInvestmentTransactionSubtype.

        Rebalancing transaction (buy or sell) with no net impact to value in the account  # noqa: E501

        :param rebalance: The rebalance of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type rebalance: str
        """

        self._rebalance = rebalance

    @property
    def return_of_principal(self):
        """Gets the return_of_principal of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Repayment of loan principal  # noqa: E501

        :return: The return_of_principal of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._return_of_principal

    @return_of_principal.setter
    def return_of_principal(self, return_of_principal):
        """Sets the return_of_principal of this StandaloneInvestmentTransactionSubtype.

        Repayment of loan principal  # noqa: E501

        :param return_of_principal: The return_of_principal of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type return_of_principal: str
        """

        self._return_of_principal = return_of_principal

    @property
    def sell(self):
        """Gets the sell of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Sell to close or decrease an existing holding  # noqa: E501

        :return: The sell of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._sell

    @sell.setter
    def sell(self, sell):
        """Sets the sell of this StandaloneInvestmentTransactionSubtype.

        Sell to close or decrease an existing holding  # noqa: E501

        :param sell: The sell of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type sell: str
        """

        self._sell = sell

    @property
    def sell_short(self):
        """Gets the sell_short of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Sell to open a short position  # noqa: E501

        :return: The sell_short of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._sell_short

    @sell_short.setter
    def sell_short(self, sell_short):
        """Sets the sell_short of this StandaloneInvestmentTransactionSubtype.

        Sell to open a short position  # noqa: E501

        :param sell_short: The sell_short of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type sell_short: str
        """

        self._sell_short = sell_short

    @property
    def short_term_capital_gain(self):
        """Gets the short_term_capital_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Short-term capital gain received as cash  # noqa: E501

        :return: The short_term_capital_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._short_term_capital_gain

    @short_term_capital_gain.setter
    def short_term_capital_gain(self, short_term_capital_gain):
        """Sets the short_term_capital_gain of this StandaloneInvestmentTransactionSubtype.

        Short-term capital gain received as cash  # noqa: E501

        :param short_term_capital_gain: The short_term_capital_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type short_term_capital_gain: str
        """

        self._short_term_capital_gain = short_term_capital_gain

    @property
    def short_term_capital_gain_reinvestment(self):
        """Gets the short_term_capital_gain_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Purchase using short-term capital gain cash proceeds  # noqa: E501

        :return: The short_term_capital_gain_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._short_term_capital_gain_reinvestment

    @short_term_capital_gain_reinvestment.setter
    def short_term_capital_gain_reinvestment(self, short_term_capital_gain_reinvestment):
        """Sets the short_term_capital_gain_reinvestment of this StandaloneInvestmentTransactionSubtype.

        Purchase using short-term capital gain cash proceeds  # noqa: E501

        :param short_term_capital_gain_reinvestment: The short_term_capital_gain_reinvestment of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type short_term_capital_gain_reinvestment: str
        """

        self._short_term_capital_gain_reinvestment = short_term_capital_gain_reinvestment

    @property
    def spin_off(self):
        """Gets the spin_off of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of stock from spin-off transaction of an existing holding  # noqa: E501

        :return: The spin_off of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._spin_off

    @spin_off.setter
    def spin_off(self, spin_off):
        """Sets the spin_off of this StandaloneInvestmentTransactionSubtype.

        Inflow of stock from spin-off transaction of an existing holding  # noqa: E501

        :param spin_off: The spin_off of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type spin_off: str
        """

        self._spin_off = spin_off

    @property
    def split(self):
        """Gets the split of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of stock from a forward split of an existing holding  # noqa: E501

        :return: The split of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._split

    @split.setter
    def split(self, split):
        """Sets the split of this StandaloneInvestmentTransactionSubtype.

        Inflow of stock from a forward split of an existing holding  # noqa: E501

        :param split: The split of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type split: str
        """

        self._split = split

    @property
    def stock_distribution(self):
        """Gets the stock_distribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Inflow of stock from a distribution  # noqa: E501

        :return: The stock_distribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._stock_distribution

    @stock_distribution.setter
    def stock_distribution(self, stock_distribution):
        """Sets the stock_distribution of this StandaloneInvestmentTransactionSubtype.

        Inflow of stock from a distribution  # noqa: E501

        :param stock_distribution: The stock_distribution of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type stock_distribution: str
        """

        self._stock_distribution = stock_distribution

    @property
    def tax(self):
        """Gets the tax of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Taxes paid on behalf of the investor  # noqa: E501

        :return: The tax of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._tax

    @tax.setter
    def tax(self, tax):
        """Sets the tax of this StandaloneInvestmentTransactionSubtype.

        Taxes paid on behalf of the investor  # noqa: E501

        :param tax: The tax of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type tax: str
        """

        self._tax = tax

    @property
    def tax_withheld(self):
        """Gets the tax_withheld of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Taxes withheld on behalf of the customer  # noqa: E501

        :return: The tax_withheld of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._tax_withheld

    @tax_withheld.setter
    def tax_withheld(self, tax_withheld):
        """Sets the tax_withheld of this StandaloneInvestmentTransactionSubtype.

        Taxes withheld on behalf of the customer  # noqa: E501

        :param tax_withheld: The tax_withheld of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type tax_withheld: str
        """

        self._tax_withheld = tax_withheld

    @property
    def transfer(self):
        """Gets the transfer of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Movement of assets into or out of an account  # noqa: E501

        :return: The transfer of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._transfer

    @transfer.setter
    def transfer(self, transfer):
        """Sets the transfer of this StandaloneInvestmentTransactionSubtype.

        Movement of assets into or out of an account  # noqa: E501

        :param transfer: The transfer of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type transfer: str
        """

        self._transfer = transfer

    @property
    def transfer_fee(self):
        """Gets the transfer_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Fees incurred for transfer of a holding or account  # noqa: E501

        :return: The transfer_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._transfer_fee

    @transfer_fee.setter
    def transfer_fee(self, transfer_fee):
        """Sets the transfer_fee of this StandaloneInvestmentTransactionSubtype.

        Fees incurred for transfer of a holding or account  # noqa: E501

        :param transfer_fee: The transfer_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type transfer_fee: str
        """

        self._transfer_fee = transfer_fee

    @property
    def trust_fee(self):
        """Gets the trust_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Fees related to adminstration of a trust account  # noqa: E501

        :return: The trust_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._trust_fee

    @trust_fee.setter
    def trust_fee(self, trust_fee):
        """Sets the trust_fee of this StandaloneInvestmentTransactionSubtype.

        Fees related to adminstration of a trust account  # noqa: E501

        :param trust_fee: The trust_fee of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type trust_fee: str
        """

        self._trust_fee = trust_fee

    @property
    def unqualified_gain(self):
        """Gets the unqualified_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Unqualified capital gain received as cash  # noqa: E501

        :return: The unqualified_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._unqualified_gain

    @unqualified_gain.setter
    def unqualified_gain(self, unqualified_gain):
        """Sets the unqualified_gain of this StandaloneInvestmentTransactionSubtype.

        Unqualified capital gain received as cash  # noqa: E501

        :param unqualified_gain: The unqualified_gain of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type unqualified_gain: str
        """

        self._unqualified_gain = unqualified_gain

    @property
    def withdrawal(self):
        """Gets the withdrawal of this StandaloneInvestmentTransactionSubtype.  # noqa: E501

        Outflow of cash from an account  # noqa: E501

        :return: The withdrawal of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :rtype: str
        """
        return self._withdrawal

    @withdrawal.setter
    def withdrawal(self, withdrawal):
        """Sets the withdrawal of this StandaloneInvestmentTransactionSubtype.

        Outflow of cash from an account  # noqa: E501

        :param withdrawal: The withdrawal of this StandaloneInvestmentTransactionSubtype.  # noqa: E501
        :type withdrawal: str
        """

        self._withdrawal = withdrawal

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StandaloneInvestmentTransactionSubtype):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StandaloneInvestmentTransactionSubtype):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class OwnerOverride(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'names': 'list[str]',
        'phone_numbers': 'list[PhoneNumber]',
        'emails': 'list[Email]',
        'addresses': 'list[Address]'
    }

    attribute_map = {
        'names': 'names',
        'phone_numbers': 'phone_numbers',
        'emails': 'emails',
        'addresses': 'addresses'
    }

    def __init__(self, names=None, phone_numbers=None, emails=None, addresses=None, local_vars_configuration=None):  # noqa: E501
        """OwnerOverride - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._names = None
        self._phone_numbers = None
        self._emails = None
        self._addresses = None
        self.discriminator = None

        if names is not None:
            self.names = names
        if phone_numbers is not None:
            self.phone_numbers = phone_numbers
        if emails is not None:
            self.emails = emails
        if addresses is not None:
            self.addresses = addresses

    @property
    def names(self):
        """Gets the names of this OwnerOverride.  # noqa: E501

        A list of names associated with the account by the financial institution. These should always be the names of individuals, even for business accounts. Note that the same name data will be used for all accounts associated with an Item.  # noqa: E501

        :return: The names of this OwnerOverride.  # noqa: E501
        :rtype: list[str]
        """
        return self._names

    @names.setter
    def names(self, names):
        """Sets the names of this OwnerOverride.

        A list of names associated with the account by the financial institution. These should always be the names of individuals, even for business accounts. Note that the same name data will be used for all accounts associated with an Item.  # noqa: E501

        :param names: The names of this OwnerOverride.  # noqa: E501
        :type names: list[str]
        """

        self._names = names

    @property
    def phone_numbers(self):
        """Gets the phone_numbers of this OwnerOverride.  # noqa: E501

        A list of phone numbers associated with the account.  # noqa: E501

        :return: The phone_numbers of this OwnerOverride.  # noqa: E501
        :rtype: list[PhoneNumber]
        """
        return self._phone_numbers

    @phone_numbers.setter
    def phone_numbers(self, phone_numbers):
        """Sets the phone_numbers of this OwnerOverride.

        A list of phone numbers associated with the account.  # noqa: E501

        :param phone_numbers: The phone_numbers of this OwnerOverride.  # noqa: E501
        :type phone_numbers: list[PhoneNumber]
        """

        self._phone_numbers = phone_numbers

    @property
    def emails(self):
        """Gets the emails of this OwnerOverride.  # noqa: E501

        A list of email addresses associated with the account.  # noqa: E501

        :return: The emails of this OwnerOverride.  # noqa: E501
        :rtype: list[Email]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this OwnerOverride.

        A list of email addresses associated with the account.  # noqa: E501

        :param emails: The emails of this OwnerOverride.  # noqa: E501
        :type emails: list[Email]
        """

        self._emails = emails

    @property
    def addresses(self):
        """Gets the addresses of this OwnerOverride.  # noqa: E501

        Data about the various addresses associated with the account.  # noqa: E501

        :return: The addresses of this OwnerOverride.  # noqa: E501
        :rtype: list[Address]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """Sets the addresses of this OwnerOverride.

        Data about the various addresses associated with the account.  # noqa: E501

        :param addresses: The addresses of this OwnerOverride.  # noqa: E501
        :type addresses: list[Address]
        """

        self._addresses = addresses

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OwnerOverride):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OwnerOverride):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class UserCustomPassword(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'str',
        'seed': 'str',
        'override_accounts': 'list[OverrideAccounts]',
        'mfa': 'MFA',
        'recaptcha': 'str',
        'force_error': 'str'
    }

    attribute_map = {
        'version': 'version',
        'seed': 'seed',
        'override_accounts': 'override_accounts',
        'mfa': 'mfa',
        'recaptcha': 'recaptcha',
        'force_error': 'force_error'
    }

    def __init__(self, version=None, seed=None, override_accounts=None, mfa=None, recaptcha=None, force_error=None, local_vars_configuration=None):  # noqa: E501
        """UserCustomPassword - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._seed = None
        self._override_accounts = None
        self._mfa = None
        self._recaptcha = None
        self._force_error = None
        self.discriminator = None

        self.version = version
        if seed is not None:
            self.seed = seed
        if override_accounts is not None:
            self.override_accounts = override_accounts
        if mfa is not None:
            self.mfa = mfa
        if recaptcha is not None:
            self.recaptcha = recaptcha
        if force_error is not None:
            self.force_error = force_error

    @property
    def version(self):
        """Gets the version of this UserCustomPassword.  # noqa: E501

        The version of the password schema to use, possible values are 1 or 2. The default value is 2. You should only specify 1 if you know it is necessary for your test suite.  # noqa: E501

        :return: The version of this UserCustomPassword.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this UserCustomPassword.

        The version of the password schema to use, possible values are 1 or 2. The default value is 2. You should only specify 1 if you know it is necessary for your test suite.  # noqa: E501

        :param version: The version of this UserCustomPassword.  # noqa: E501
        :type version: str
        """

        self._version = version

    @property
    def seed(self):
        """Gets the seed of this UserCustomPassword.  # noqa: E501

        A seed, in the form of a string, that will be used to randomly generate account and transaction data, if this data is not specified using the `override_accounts` argument. If no seed is specified, the randomly generated data will be different each time.  Note that transactions data is generated relative to the Item's creation date. Different Items created on different dates with the same seed for transactions data will have different dates for the transactions. The number of days between each transaction and the Item creation will remain constant. For example, an Item created on December 15 might show a transaction on December 14. An Item created on December 20, using the same seed, would show that same transaction occurring on December 19.  # noqa: E501

        :return: The seed of this UserCustomPassword.  # noqa: E501
        :rtype: str
        """
        return self._seed

    @seed.setter
    def seed(self, seed):
        """Sets the seed of this UserCustomPassword.

        A seed, in the form of a string, that will be used to randomly generate account and transaction data, if this data is not specified using the `override_accounts` argument. If no seed is specified, the randomly generated data will be different each time.  Note that transactions data is generated relative to the Item's creation date. Different Items created on different dates with the same seed for transactions data will have different dates for the transactions. The number of days between each transaction and the Item creation will remain constant. For example, an Item created on December 15 might show a transaction on December 14. An Item created on December 20, using the same seed, would show that same transaction occurring on December 19.  # noqa: E501

        :param seed: The seed of this UserCustomPassword.  # noqa: E501
        :type seed: str
        """

        self._seed = seed

    @property
    def override_accounts(self):
        """Gets the override_accounts of this UserCustomPassword.  # noqa: E501

        An array of account overrides to configure the accounts for the Item. By default, if no override is specified, transactions and account data will be randomly generated based on the account type and subtype, and other products will have fixed or empty data.  # noqa: E501

        :return: The override_accounts of this UserCustomPassword.  # noqa: E501
        :rtype: list[OverrideAccounts]
        """
        return self._override_accounts

    @override_accounts.setter
    def override_accounts(self, override_accounts):
        """Sets the override_accounts of this UserCustomPassword.

        An array of account overrides to configure the accounts for the Item. By default, if no override is specified, transactions and account data will be randomly generated based on the account type and subtype, and other products will have fixed or empty data.  # noqa: E501

        :param override_accounts: The override_accounts of this UserCustomPassword.  # noqa: E501
        :type override_accounts: list[OverrideAccounts]
        """

        self._override_accounts = override_accounts

    @property
    def mfa(self):
        """Gets the mfa of this UserCustomPassword.  # noqa: E501


        :return: The mfa of this UserCustomPassword.  # noqa: E501
        :rtype: MFA
        """
        return self._mfa

    @mfa.setter
    def mfa(self, mfa):
        """Sets the mfa of this UserCustomPassword.


        :param mfa: The mfa of this UserCustomPassword.  # noqa: E501
        :type mfa: MFA
        """

        self._mfa = mfa

    @property
    def recaptcha(self):
        """Gets the recaptcha of this UserCustomPassword.  # noqa: E501

        You may trigger a reCAPTCHA in Plaid Link in the Sandbox environment by using the recaptcha field. Possible values are `good` or `bad`. A value of `good` will result in successful Item creation and `bad` will result in a `RECAPTCHA_BAD` error to simulate a failed reCAPTCHA. Both values require the reCAPTCHA to be manually solved within Plaid Link.  # noqa: E501

        :return: The recaptcha of this UserCustomPassword.  # noqa: E501
        :rtype: str
        """
        return self._recaptcha

    @recaptcha.setter
    def recaptcha(self, recaptcha):
        """Sets the recaptcha of this UserCustomPassword.

        You may trigger a reCAPTCHA in Plaid Link in the Sandbox environment by using the recaptcha field. Possible values are `good` or `bad`. A value of `good` will result in successful Item creation and `bad` will result in a `RECAPTCHA_BAD` error to simulate a failed reCAPTCHA. Both values require the reCAPTCHA to be manually solved within Plaid Link.  # noqa: E501

        :param recaptcha: The recaptcha of this UserCustomPassword.  # noqa: E501
        :type recaptcha: str
        """

        self._recaptcha = recaptcha

    @property
    def force_error(self):
        """Gets the force_error of this UserCustomPassword.  # noqa: E501

        An error code to force on Item creation. Possible values are:  `\"INSTITUTION_NOT_RESPONDING\"` `\"INSTITUTION_NO_LONGER_SUPPORTED\"` `\"INVALID_CREDENTIALS\"` `\"INVALID_MFA\"` `\"ITEM_LOCKED\"` `\"ITEM_LOGIN_REQUIRED\"` `\"ITEM_NOT_SUPPORTED\"` `\"INVALID_LINK_TOKEN\"` `\"MFA_NOT_SUPPORTED\"` `\"NO_ACCOUNTS\"` `\"PLAID_ERROR\"` `\"PRODUCTS_NOT_SUPPORTED\"` `\"USER_SETUP_REQUIRED\"`  # noqa: E501

        :return: The force_error of this UserCustomPassword.  # noqa: E501
        :rtype: str
        """
        return self._force_error

    @force_error.setter
    def force_error(self, force_error):
        """Sets the force_error of this UserCustomPassword.

        An error code to force on Item creation. Possible values are:  `\"INSTITUTION_NOT_RESPONDING\"` `\"INSTITUTION_NO_LONGER_SUPPORTED\"` `\"INVALID_CREDENTIALS\"` `\"INVALID_MFA\"` `\"ITEM_LOCKED\"` `\"ITEM_LOGIN_REQUIRED\"` `\"ITEM_NOT_SUPPORTED\"` `\"INVALID_LINK_TOKEN\"` `\"MFA_NOT_SUPPORTED\"` `\"NO_ACCOUNTS\"` `\"PLAID_ERROR\"` `\"PRODUCTS_NOT_SUPPORTED\"` `\"USER_SETUP_REQUIRED\"`  # noqa: E501

        :param force_error: The force_error of this UserCustomPassword.  # noqa: E501
        :type force_error: str
        """

        self._force_error = force_error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserCustomPassword):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserCustomPassword):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class Security(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'security_id': 'str',
        'isin': 'str',
        'cusip': 'str',
        'sedol': 'str',
        'institution_security_id': 'str',
        'institution_id': 'str',
        'proxy_security_id': 'str',
        'name': 'str',
        'ticker_symbol': 'str',
        'is_cash_equivalent': 'bool',
        'type': 'str',
        'close_price': 'float',
        'close_price_as_of': 'str',
        'iso_currency_code': 'str',
        'unofficial_currency_code': 'str'
    }

    attribute_map = {
        'security_id': 'security_id',
        'isin': 'isin',
        'cusip': 'cusip',
        'sedol': 'sedol',
        'institution_security_id': 'institution_security_id',
        'institution_id': 'institution_id',
        'proxy_security_id': 'proxy_security_id',
        'name': 'name',
        'ticker_symbol': 'ticker_symbol',
        'is_cash_equivalent': 'is_cash_equivalent',
        'type': 'type',
        'close_price': 'close_price',
        'close_price_as_of': 'close_price_as_of',
        'iso_currency_code': 'iso_currency_code',
        'unofficial_currency_code': 'unofficial_currency_code'
    }

    def __init__(self, security_id=None, isin=None, cusip=None, sedol=None, institution_security_id=None, institution_id=None, proxy_security_id=None, name=None, ticker_symbol=None, is_cash_equivalent=None, type=None, close_price=None, close_price_as_of=None, iso_currency_code=None, unofficial_currency_code=None, local_vars_configuration=None):  # noqa: E501
        """Security - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._security_id = None
        self._isin = None
        self._cusip = None
        self._sedol = None
        self._institution_security_id = None
        self._institution_id = None
        self._proxy_security_id = None
        self._name = None
        self._ticker_symbol = None
        self._is_cash_equivalent = None
        self._type = None
        self._close_price = None
        self._close_price_as_of = None
        self._iso_currency_code = None
        self._unofficial_currency_code = None
        self.discriminator = None

        if security_id is not None:
            self.security_id = security_id
        self.isin = isin
        self.cusip = cusip
        self.sedol = sedol
        self.institution_security_id = institution_security_id
        self.institution_id = institution_id
        self.proxy_security_id = proxy_security_id
        self.name = name
        self.ticker_symbol = ticker_symbol
        if is_cash_equivalent is not None:
            self.is_cash_equivalent = is_cash_equivalent
        if type is not None:
            self.type = type
        self.close_price = close_price
        self.close_price_as_of = close_price_as_of
        self.iso_currency_code = iso_currency_code
        self.unofficial_currency_code = unofficial_currency_code

    @property
    def security_id(self):
        """Gets the security_id of this Security.  # noqa: E501

        A unique, Plaid-specific identifier for the security, used to associate securities with holdings. Like all Plaid identifiers, the `security_id` is case sensitive.  # noqa: E501

        :return: The security_id of this Security.  # noqa: E501
        :rtype: str
        """
        return self._security_id

    @security_id.setter
    def security_id(self, security_id):
        """Sets the security_id of this Security.

        A unique, Plaid-specific identifier for the security, used to associate securities with holdings. Like all Plaid identifiers, the `security_id` is case sensitive.  # noqa: E501

        :param security_id: The security_id of this Security.  # noqa: E501
        :type security_id: str
        """

        self._security_id = security_id

    @property
    def isin(self):
        """Gets the isin of this Security.  # noqa: E501

        12-character ISIN, a globally unique securities identifier.  # noqa: E501

        :return: The isin of this Security.  # noqa: E501
        :rtype: str
        """
        return self._isin

    @isin.setter
    def isin(self, isin):
        """Sets the isin of this Security.

        12-character ISIN, a globally unique securities identifier.  # noqa: E501

        :param isin: The isin of this Security.  # noqa: E501
        :type isin: str
        """

        self._isin = isin

    @property
    def cusip(self):
        """Gets the cusip of this Security.  # noqa: E501

        9-character CUSIP, an identifier assigned to North American securities.  # noqa: E501

        :return: The cusip of this Security.  # noqa: E501
        :rtype: str
        """
        return self._cusip

    @cusip.setter
    def cusip(self, cusip):
        """Sets the cusip of this Security.

        9-character CUSIP, an identifier assigned to North American securities.  # noqa: E501

        :param cusip: The cusip of this Security.  # noqa: E501
        :type cusip: str
        """

        self._cusip = cusip

    @property
    def sedol(self):
        """Gets the sedol of this Security.  # noqa: E501

        7-character SEDOL, an identifier assigned to securities in the UK.  # noqa: E501

        :return: The sedol of this Security.  # noqa: E501
        :rtype: str
        """
        return self._sedol

    @sedol.setter
    def sedol(self, sedol):
        """Sets the sedol of this Security.

        7-character SEDOL, an identifier assigned to securities in the UK.  # noqa: E501

        :param sedol: The sedol of this Security.  # noqa: E501
        :type sedol: str
        """

        self._sedol = sedol

    @property
    def institution_security_id(self):
        """Gets the institution_security_id of this Security.  # noqa: E501

        An identifier given to the security by the institution  # noqa: E501

        :return: The institution_security_id of this Security.  # noqa: E501
        :rtype: str
        """
        return self._institution_security_id

    @institution_security_id.setter
    def institution_security_id(self, institution_security_id):
        """Sets the institution_security_id of this Security.

        An identifier given to the security by the institution  # noqa: E501

        :param institution_security_id: The institution_security_id of this Security.  # noqa: E501
        :type institution_security_id: str
        """

        self._institution_security_id = institution_security_id

    @property
    def institution_id(self):
        """Gets the institution_id of this Security.  # noqa: E501

        If `institution_security_id` is present, this field indicates the Plaid `institution_id` of the institution to whom the identifier belongs.  # noqa: E501

        :return: The institution_id of this Security.  # noqa: E501
        :rtype: str
        """
        return self._institution_id

    @institution_id.setter
    def institution_id(self, institution_id):
        """Sets the institution_id of this Security.

        If `institution_security_id` is present, this field indicates the Plaid `institution_id` of the institution to whom the identifier belongs.  # noqa: E501

        :param institution_id: The institution_id of this Security.  # noqa: E501
        :type institution_id: str
        """

        self._institution_id = institution_id

    @property
    def proxy_security_id(self):
        """Gets the proxy_security_id of this Security.  # noqa: E501

        In certain cases, Plaid will provide the ID of another security whose performance resembles this security, typically when the original security has low volume, or when a private security can be modeled with a publicly traded security.  # noqa: E501

        :return: The proxy_security_id of this Security.  # noqa: E501
        :rtype: str
        """
        return self._proxy_security_id

    @proxy_security_id.setter
    def proxy_security_id(self, proxy_security_id):
        """Sets the proxy_security_id of this Security.

        In certain cases, Plaid will provide the ID of another security whose performance resembles this security, typically when the original security has low volume, or when a private security can be modeled with a publicly traded security.  # noqa: E501

        :param proxy_security_id: The proxy_security_id of this Security.  # noqa: E501
        :type proxy_security_id: str
        """

        self._proxy_security_id = proxy_security_id

    @property
    def name(self):
        """Gets the name of this Security.  # noqa: E501

        A descriptive name for the security, suitable for display.  # noqa: E501

        :return: The name of this Security.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Security.

        A descriptive name for the security, suitable for display.  # noqa: E501

        :param name: The name of this Security.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def ticker_symbol(self):
        """Gets the ticker_symbol of this Security.  # noqa: E501

        The security’s trading symbol for publicly traded securities, and otherwise a short identifier if available.  # noqa: E501

        :return: The ticker_symbol of this Security.  # noqa: E501
        :rtype: str
        """
        return self._ticker_symbol

    @ticker_symbol.setter
    def ticker_symbol(self, ticker_symbol):
        """Sets the ticker_symbol of this Security.

        The security’s trading symbol for publicly traded securities, and otherwise a short identifier if available.  # noqa: E501

        :param ticker_symbol: The ticker_symbol of this Security.  # noqa: E501
        :type ticker_symbol: str
        """

        self._ticker_symbol = ticker_symbol

    @property
    def is_cash_equivalent(self):
        """Gets the is_cash_equivalent of this Security.  # noqa: E501

        Indicates that a security is a highly liquid asset and can be treated like cash.  # noqa: E501

        :return: The is_cash_equivalent of this Security.  # noqa: E501
        :rtype: bool
        """
        return self._is_cash_equivalent

    @is_cash_equivalent.setter
    def is_cash_equivalent(self, is_cash_equivalent):
        """Sets the is_cash_equivalent of this Security.

        Indicates that a security is a highly liquid asset and can be treated like cash.  # noqa: E501

        :param is_cash_equivalent: The is_cash_equivalent of this Security.  # noqa: E501
        :type is_cash_equivalent: bool
        """

        self._is_cash_equivalent = is_cash_equivalent

    @property
    def type(self):
        """Gets the type of this Security.  # noqa: E501

        The security type of the holding. Valid security types are:  `cash`: Cash, currency, and money market funds  `derivative`: Options, warrants, and other derivative instruments  `equity`: Domestic and foreign equities  `etf`: Multi-asset exchange-traded investment funds  `fixed income`: Bonds and certificates of deposit (CDs)  `loan`: Loans and loan receivables.  `mutual fund`: Open- and closed-end vehicles pooling funds of multiple investors.  `other`: Unknown or other investment types  # noqa: E501

        :return: The type of this Security.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Security.

        The security type of the holding. Valid security types are:  `cash`: Cash, currency, and money market funds  `derivative`: Options, warrants, and other derivative instruments  `equity`: Domestic and foreign equities  `etf`: Multi-asset exchange-traded investment funds  `fixed income`: Bonds and certificates of deposit (CDs)  `loan`: Loans and loan receivables.  `mutual fund`: Open- and closed-end vehicles pooling funds of multiple investors.  `other`: Unknown or other investment types  # noqa: E501

        :param type: The type of this Security.  # noqa: E501
        :type type: str
        """

        self._type = type

    @property
    def close_price(self):
        """Gets the close_price of this Security.  # noqa: E501

        Price of the security at the close of the previous trading session. `null` for non-public securities.  # noqa: E501

        :return: The close_price of this Security.  # noqa: E501
        :rtype: float
        """
        return self._close_price

    @close_price.setter
    def close_price(self, close_price):
        """Sets the close_price of this Security.

        Price of the security at the close of the previous trading session. `null` for non-public securities.  # noqa: E501

        :param close_price: The close_price of this Security.  # noqa: E501
        :type close_price: float
        """

        self._close_price = close_price

    @property
    def close_price_as_of(self):
        """Gets the close_price_as_of of this Security.  # noqa: E501

        Date for which `close_price` is accurate. Always `null` if `close_price` is `null`.  # noqa: E501

        :return: The close_price_as_of of this Security.  # noqa: E501
        :rtype: str
        """
        return self._close_price_as_of

    @close_price_as_of.setter
    def close_price_as_of(self, close_price_as_of):
        """Sets the close_price_as_of of this Security.

        Date for which `close_price` is accurate. Always `null` if `close_price` is `null`.  # noqa: E501

        :param close_price_as_of: The close_price_as_of of this Security.  # noqa: E501
        :type close_price_as_of: str
        """

        self._close_price_as_of = close_price_as_of

    @property
    def iso_currency_code(self):
        """Gets the iso_currency_code of this Security.  # noqa: E501

        The ISO-4217 currency code of the price given. Always `null` if `unofficial_currency_code` is non-`null`.  # noqa: E501

        :return: The iso_currency_code of this Security.  # noqa: E501
        :rtype: str
        """
        return self._iso_currency_code

    @iso_currency_code.setter
    def iso_currency_code(self, iso_currency_code):
        """Sets the iso_currency_code of this Security.

        The ISO-4217 currency code of the price given. Always `null` if `unofficial_currency_code` is non-`null`.  # noqa: E501

        :param iso_currency_code: The iso_currency_code of this Security.  # noqa: E501
        :type iso_currency_code: str
        """

        self._iso_currency_code = iso_currency_code

    @property
    def unofficial_currency_code(self):
        """Gets the unofficial_currency_code of this Security.  # noqa: E501

        The unofficial currency code associated with the security. Always `null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.  # noqa: E501

        :return: The unofficial_currency_code of this Security.  # noqa: E501
        :rtype: str
        """
        return self._unofficial_currency_code

    @unofficial_currency_code.setter
    def unofficial_currency_code(self, unofficial_currency_code):
        """Sets the unofficial_currency_code of this Security.

        The unofficial currency code associated with the security. Always `null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.  # noqa: E501

        :param unofficial_currency_code: The unofficial_currency_code of this Security.  # noqa: E501
        :type unofficial_currency_code: str
        """

        self._unofficial_currency_code = unofficial_currency_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Security):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Security):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class BankTransfer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'ach_class': 'ACHClass',
        'account_id': 'str',
        'type': 'BankTransferType',
        'user': 'BankTransferUser',
        'amount': 'str',
        'iso_currency_code': 'str',
        'description': 'str',
        'created': 'str',
        'status': 'BankTransferStatus',
        'network': 'BankTransferNetwork',
        'cancellable': 'bool',
        'failure_reason': 'BankTransferFailure',
        'custom_tag': 'str',
        'metadata': 'dict(str, str)',
        'origination_account_id': 'str',
        'direction': 'BankTransferDirection'
    }

    attribute_map = {
        'id': 'id',
        'ach_class': 'ach_class',
        'account_id': 'account_id',
        'type': 'type',
        'user': 'user',
        'amount': 'amount',
        'iso_currency_code': 'iso_currency_code',
        'description': 'description',
        'created': 'created',
        'status': 'status',
        'network': 'network',
        'cancellable': 'cancellable',
        'failure_reason': 'failure_reason',
        'custom_tag': 'custom_tag',
        'metadata': 'metadata',
        'origination_account_id': 'origination_account_id',
        'direction': 'direction'
    }

    def __init__(self, id=None, ach_class=None, account_id=None, type=None, user=None, amount=None, iso_currency_code=None, description=None, created=None, status=None, network=None, cancellable=None, failure_reason=None, custom_tag=None, metadata=None, origination_account_id=None, direction=None, local_vars_configuration=None):  # noqa: E501
        """BankTransfer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._ach_class = None
        self._account_id = None
        self._type = None
        self._user = None
        self._amount = None
        self._iso_currency_code = None
        self._description = None
        self._created = None
        self._status = None
        self._network = None
        self._cancellable = None
        self._failure_reason = None
        self._custom_tag = None
        self._metadata = None
        self._origination_account_id = None
        self._direction = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if ach_class is not None:
            self.ach_class = ach_class
        if account_id is not None:
            self.account_id = account_id
        if type is not None:
            self.type = type
        if user is not None:
            self.user = user
        if amount is not None:
            self.amount = amount
        if iso_currency_code is not None:
            self.iso_currency_code = iso_currency_code
        if description is not None:
            self.description = description
        if created is not None:
            self.created = created
        if status is not None:
            self.status = status
        if network is not None:
            self.network = network
        if cancellable is not None:
            self.cancellable = cancellable
        self.failure_reason = failure_reason
        self.custom_tag = custom_tag
        self.metadata = metadata
        if origination_account_id is not None:
            self.origination_account_id = origination_account_id
        if direction is not None:
            self.direction = direction

    @property
    def id(self):
        """Gets the id of this BankTransfer.  # noqa: E501

        Plaid’s unique identifier for a bank transfer.  # noqa: E501

        :return: The id of this BankTransfer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BankTransfer.

        Plaid’s unique identifier for a bank transfer.  # noqa: E501

        :param id: The id of this BankTransfer.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def ach_class(self):
        """Gets the ach_class of this BankTransfer.  # noqa: E501


        :return: The ach_class of this BankTransfer.  # noqa: E501
        :rtype: ACHClass
        """
        return self._ach_class

    @ach_class.setter
    def ach_class(self, ach_class):
        """Sets the ach_class of this BankTransfer.


        :param ach_class: The ach_class of this BankTransfer.  # noqa: E501
        :type ach_class: ACHClass
        """

        self._ach_class = ach_class

    @property
    def account_id(self):
        """Gets the account_id of this BankTransfer.  # noqa: E501

        The account ID that should be credited/debited for this bank transfer.  # noqa: E501

        :return: The account_id of this BankTransfer.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this BankTransfer.

        The account ID that should be credited/debited for this bank transfer.  # noqa: E501

        :param account_id: The account_id of this BankTransfer.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def type(self):
        """Gets the type of this BankTransfer.  # noqa: E501


        :return: The type of this BankTransfer.  # noqa: E501
        :rtype: BankTransferType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this BankTransfer.


        :param type: The type of this BankTransfer.  # noqa: E501
        :type type: BankTransferType
        """

        self._type = type

    @property
    def user(self):
        """Gets the user of this BankTransfer.  # noqa: E501


        :return: The user of this BankTransfer.  # noqa: E501
        :rtype: BankTransferUser
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this BankTransfer.


        :param user: The user of this BankTransfer.  # noqa: E501
        :type user: BankTransferUser
        """

        self._user = user

    @property
    def amount(self):
        """Gets the amount of this BankTransfer.  # noqa: E501

        The amount of the transfer (decimal string with two digits of precision e.g. “10.00”).  # noqa: E501

        :return: The amount of this BankTransfer.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this BankTransfer.

        The amount of the transfer (decimal string with two digits of precision e.g. “10.00”).  # noqa: E501

        :param amount: The amount of this BankTransfer.  # noqa: E501
        :type amount: str
        """

        self._amount = amount

    @property
    def iso_currency_code(self):
        """Gets the iso_currency_code of this BankTransfer.  # noqa: E501

        The currency of the transfer amount, e.g. \"USD\"  # noqa: E501

        :return: The iso_currency_code of this BankTransfer.  # noqa: E501
        :rtype: str
        """
        return self._iso_currency_code

    @iso_currency_code.setter
    def iso_currency_code(self, iso_currency_code):
        """Sets the iso_currency_code of this BankTransfer.

        The currency of the transfer amount, e.g. \"USD\"  # noqa: E501

        :param iso_currency_code: The iso_currency_code of this BankTransfer.  # noqa: E501
        :type iso_currency_code: str
        """

        self._iso_currency_code = iso_currency_code

    @property
    def description(self):
        """Gets the description of this BankTransfer.  # noqa: E501

        The description of the transfer.  # noqa: E501

        :return: The description of this BankTransfer.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BankTransfer.

        The description of the transfer.  # noqa: E501

        :param description: The description of this BankTransfer.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def created(self):
        """Gets the created of this BankTransfer.  # noqa: E501

        The datetime when this bank transfer was created. This will be of the form `2006-01-02T15:04:05Z`  # noqa: E501

        :return: The created of this BankTransfer.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this BankTransfer.

        The datetime when this bank transfer was created. This will be of the form `2006-01-02T15:04:05Z`  # noqa: E501

        :param created: The created of this BankTransfer.  # noqa: E501
        :type created: str
        """

        self._created = created

    @property
    def status(self):
        """Gets the status of this BankTransfer.  # noqa: E501


        :return: The status of this BankTransfer.  # noqa: E501
        :rtype: BankTransferStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BankTransfer.


        :param status: The status of this BankTransfer.  # noqa: E501
        :type status: BankTransferStatus
        """

        self._status = status

    @property
    def network(self):
        """Gets the network of this BankTransfer.  # noqa: E501


        :return: The network of this BankTransfer.  # noqa: E501
        :rtype: BankTransferNetwork
        """
        return self._network

    @network.setter
    def network(self, network):
        """Sets the network of this BankTransfer.


        :param network: The network of this BankTransfer.  # noqa: E501
        :type network: BankTransferNetwork
        """

        self._network = network

    @property
    def cancellable(self):
        """Gets the cancellable of this BankTransfer.  # noqa: E501

        When `true`, you can still cancel this bank transfer.  # noqa: E501

        :return: The cancellable of this BankTransfer.  # noqa: E501
        :rtype: bool
        """
        return self._cancellable

    @cancellable.setter
    def cancellable(self, cancellable):
        """Sets the cancellable of this BankTransfer.

        When `true`, you can still cancel this bank transfer.  # noqa: E501

        :param cancellable: The cancellable of this BankTransfer.  # noqa: E501
        :type cancellable: bool
        """

        self._cancellable = cancellable

    @property
    def failure_reason(self):
        """Gets the failure_reason of this BankTransfer.  # noqa: E501


        :return: The failure_reason of this BankTransfer.  # noqa: E501
        :rtype: BankTransferFailure
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this BankTransfer.


        :param failure_reason: The failure_reason of this BankTransfer.  # noqa: E501
        :type failure_reason: BankTransferFailure
        """

        self._failure_reason = failure_reason

    @property
    def custom_tag(self):
        """Gets the custom_tag of this BankTransfer.  # noqa: E501

        A string containing the custom tag provided by the client in the create request. Will be null if not provided.  # noqa: E501

        :return: The custom_tag of this BankTransfer.  # noqa: E501
        :rtype: str
        """
        return self._custom_tag

    @custom_tag.setter
    def custom_tag(self, custom_tag):
        """Sets the custom_tag of this BankTransfer.

        A string containing the custom tag provided by the client in the create request. Will be null if not provided.  # noqa: E501

        :param custom_tag: The custom_tag of this BankTransfer.  # noqa: E501
        :type custom_tag: str
        """

        self._custom_tag = custom_tag

    @property
    def metadata(self):
        """Gets the metadata of this BankTransfer.  # noqa: E501

        The Metadata object is a mapping of client-provided String fields to any String value. The following limitations apply: - The JSON values must be Strings (no nested JSON objects allowed) - Only ASCII characters may be used - Maximum of 50 key/value pairs - Maximum key length of 40 characters - Maximum value length of 500 characters   # noqa: E501

        :return: The metadata of this BankTransfer.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this BankTransfer.

        The Metadata object is a mapping of client-provided String fields to any String value. The following limitations apply: - The JSON values must be Strings (no nested JSON objects allowed) - Only ASCII characters may be used - Maximum of 50 key/value pairs - Maximum key length of 40 characters - Maximum value length of 500 characters   # noqa: E501

        :param metadata: The metadata of this BankTransfer.  # noqa: E501
        :type metadata: dict(str, str)
        """

        self._metadata = metadata

    @property
    def origination_account_id(self):
        """Gets the origination_account_id of this BankTransfer.  # noqa: E501

        Plaid’s unique identifier for the origination account that was used for this transfer.  # noqa: E501

        :return: The origination_account_id of this BankTransfer.  # noqa: E501
        :rtype: str
        """
        return self._origination_account_id

    @origination_account_id.setter
    def origination_account_id(self, origination_account_id):
        """Sets the origination_account_id of this BankTransfer.

        Plaid’s unique identifier for the origination account that was used for this transfer.  # noqa: E501

        :param origination_account_id: The origination_account_id of this BankTransfer.  # noqa: E501
        :type origination_account_id: str
        """

        self._origination_account_id = origination_account_id

    @property
    def direction(self):
        """Gets the direction of this BankTransfer.  # noqa: E501


        :return: The direction of this BankTransfer.  # noqa: E501
        :rtype: BankTransferDirection
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this BankTransfer.


        :param direction: The direction of this BankTransfer.  # noqa: E501
        :type direction: BankTransferDirection
        """

        self._direction = direction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BankTransfer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BankTransfer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class StudentLoanRepaymentModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'non_repayment_months': 'float',
        'repayment_months': 'float'
    }

    attribute_map = {
        'type': 'type',
        'non_repayment_months': 'non_repayment_months',
        'repayment_months': 'repayment_months'
    }

    def __init__(self, type=None, non_repayment_months=None, repayment_months=None, local_vars_configuration=None):  # noqa: E501
        """StudentLoanRepaymentModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._non_repayment_months = None
        self._repayment_months = None
        self.discriminator = None

        self.type = type
        self.non_repayment_months = non_repayment_months
        self.repayment_months = repayment_months

    @property
    def type(self):
        """Gets the type of this StudentLoanRepaymentModel.  # noqa: E501

        The only currently supported value for this field is `standard`.  # noqa: E501

        :return: The type of this StudentLoanRepaymentModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this StudentLoanRepaymentModel.

        The only currently supported value for this field is `standard`.  # noqa: E501

        :param type: The type of this StudentLoanRepaymentModel.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def non_repayment_months(self):
        """Gets the non_repayment_months of this StudentLoanRepaymentModel.  # noqa: E501

        Configures the number of months before repayment starts.  # noqa: E501

        :return: The non_repayment_months of this StudentLoanRepaymentModel.  # noqa: E501
        :rtype: float
        """
        return self._non_repayment_months

    @non_repayment_months.setter
    def non_repayment_months(self, non_repayment_months):
        """Sets the non_repayment_months of this StudentLoanRepaymentModel.

        Configures the number of months before repayment starts.  # noqa: E501

        :param non_repayment_months: The non_repayment_months of this StudentLoanRepaymentModel.  # noqa: E501
        :type non_repayment_months: float
        """
        if self.local_vars_configuration.client_side_validation and non_repayment_months is None:  # noqa: E501
            raise ValueError("Invalid value for `non_repayment_months`, must not be `None`")  # noqa: E501

        self._non_repayment_months = non_repayment_months

    @property
    def repayment_months(self):
        """Gets the repayment_months of this StudentLoanRepaymentModel.  # noqa: E501

        Configures the number of months of repayments before the loan is paid off.  # noqa: E501

        :return: The repayment_months of this StudentLoanRepaymentModel.  # noqa: E501
        :rtype: float
        """
        return self._repayment_months

    @repayment_months.setter
    def repayment_months(self, repayment_months):
        """Sets the repayment_months of this StudentLoanRepaymentModel.

        Configures the number of months of repayments before the loan is paid off.  # noqa: E501

        :param repayment_months: The repayment_months of this StudentLoanRepaymentModel.  # noqa: E501
        :type repayment_months: float
        """
        if self.local_vars_configuration.client_side_validation and repayment_months is None:  # noqa: E501
            raise ValueError("Invalid value for `repayment_months`, must not be `None`")  # noqa: E501

        self._repayment_months = repayment_months

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StudentLoanRepaymentModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StudentLoanRepaymentModel):
            return True

        return self.to_dict() != other.to_dict()



import time

from plaid.errors import ItemError
from tests.integration.util import (
    create_client,
    SANDBOX_INSTITUTION,
)

access_token = None

# NOTE: Data is only generated over the past 2 years.  Ensure that the date
# range used for transactions/get is within 2 years old

START_DATE = '2019-01-01'
END_DATE = '2020-01-01'


def setup_module(module):
    client = create_client()
    pt_response = client.Sandbox.public_token.create(
        SANDBOX_INSTITUTION, ['transactions'],
        transactions__start_date=START_DATE,
        transactions__end_date=END_DATE,
    )
    exchange_response = client.Item.public_token.exchange(
        pt_response['public_token'])
    global access_token
    access_token = exchange_response['access_token']


def get_transactions_with_retries(client,
                                  access_token,
                                  start_date,
                                  end_date,
                                  account_ids=None,
                                  count=None,
                                  offset=None,
                                  num_retries=20):
    response = None
    for i in range(num_retries):
        try:
            response = client.Transactions.get(access_token,
                                               start_date,
                                               end_date,
                                               account_ids=account_ids,
                                               count=count,
                                               offset=offset)
        except ItemError as ie:
            if ie.code == u'PRODUCT_NOT_READY':
                time.sleep(5)
                continue
            else:
                raise ie
        break
    return response


def refresh_transactions(client,
                         access_token):
    return client.Transactions.refresh(access_token)


def teardown_module(module):
    client = create_client()
    client.Item.remove(access_token)


def test_get():
    client = create_client()

    response = get_transactions_with_retries(client,
                                             access_token,
                                             START_DATE,
                                             END_DATE,
                                             num_retries=10)
    assert response['accounts'] is not None
    assert response['transactions'] is not None

    # get transactions for selected accounts
    account_id = response['accounts'][0]['account_id']
    response = get_transactions_with_retries(client,
                                             access_token,
                                             START_DATE,
                                             END_DATE,
                                             account_ids=[account_id],
                                             num_retries=10)
    assert response['transactions'] is not None


def test_get_with_options():
    client = create_client()
    response = get_transactions_with_retries(client,
                                             access_token,
                                             START_DATE,
                                             END_DATE,
                                             count=2,
                                             offset=1)
    assert len(response['transactions']) == 2


def test_refresh():
    client = create_client()

    response = refresh_transactions(client,
                                    access_token)
    # response should be empty (aside from request_id)
    assert response is not None



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class BankTransferListRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_id': 'str',
        'secret': 'str',
        'start_date': 'str',
        'end_date': 'str',
        'count': 'float',
        'offset': 'float',
        'origination_account_id': 'str',
        'direction': 'BankTransferDirection'
    }

    attribute_map = {
        'client_id': 'client_id',
        'secret': 'secret',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'count': 'count',
        'offset': 'offset',
        'origination_account_id': 'origination_account_id',
        'direction': 'direction'
    }

    def __init__(self, client_id=None, secret=None, start_date=None, end_date=None, count=25, offset=0, origination_account_id=None, direction=None, local_vars_configuration=None):  # noqa: E501
        """BankTransferListRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_id = None
        self._secret = None
        self._start_date = None
        self._end_date = None
        self._count = None
        self._offset = None
        self._origination_account_id = None
        self._direction = None
        self.discriminator = None

        self.client_id = client_id
        self.secret = secret
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if count is not None:
            self.count = count
        if offset is not None:
            self.offset = offset
        if origination_account_id is not None:
            self.origination_account_id = origination_account_id
        if direction is not None:
            self.direction = direction

    @property
    def client_id(self):
        """Gets the client_id of this BankTransferListRequest.  # noqa: E501

        Your Plaid API `client_id`.  # noqa: E501

        :return: The client_id of this BankTransferListRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this BankTransferListRequest.

        Your Plaid API `client_id`.  # noqa: E501

        :param client_id: The client_id of this BankTransferListRequest.  # noqa: E501
        :type client_id: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def secret(self):
        """Gets the secret of this BankTransferListRequest.  # noqa: E501

        Your Plaid API `secret`.  # noqa: E501

        :return: The secret of this BankTransferListRequest.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this BankTransferListRequest.

        Your Plaid API `secret`.  # noqa: E501

        :param secret: The secret of this BankTransferListRequest.  # noqa: E501
        :type secret: str
        """
        if self.local_vars_configuration.client_side_validation and secret is None:  # noqa: E501
            raise ValueError("Invalid value for `secret`, must not be `None`")  # noqa: E501

        self._secret = secret

    @property
    def start_date(self):
        """Gets the start_date of this BankTransferListRequest.  # noqa: E501

        The start datetime of bank transfers to list. This should be of the form `2006-01-02T15:04:05Z`.  # noqa: E501

        :return: The start_date of this BankTransferListRequest.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this BankTransferListRequest.

        The start datetime of bank transfers to list. This should be of the form `2006-01-02T15:04:05Z`.  # noqa: E501

        :param start_date: The start_date of this BankTransferListRequest.  # noqa: E501
        :type start_date: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this BankTransferListRequest.  # noqa: E501

        The end datetime of bank transfers to list. This should be of the form `2006-01-02T15:04:05Z`.  # noqa: E501

        :return: The end_date of this BankTransferListRequest.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this BankTransferListRequest.

        The end datetime of bank transfers to list. This should be of the form `2006-01-02T15:04:05Z`.  # noqa: E501

        :param end_date: The end_date of this BankTransferListRequest.  # noqa: E501
        :type end_date: str
        """

        self._end_date = end_date

    @property
    def count(self):
        """Gets the count of this BankTransferListRequest.  # noqa: E501

        The maximum number of bank transfers to return.  # noqa: E501

        :return: The count of this BankTransferListRequest.  # noqa: E501
        :rtype: float
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this BankTransferListRequest.

        The maximum number of bank transfers to return.  # noqa: E501

        :param count: The count of this BankTransferListRequest.  # noqa: E501
        :type count: float
        """
        if (self.local_vars_configuration.client_side_validation and
                count is not None and count > 25):  # noqa: E501
            raise ValueError("Invalid value for `count`, must be a value less than or equal to `25`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                count is not None and count < 0):  # noqa: E501
            raise ValueError("Invalid value for `count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._count = count

    @property
    def offset(self):
        """Gets the offset of this BankTransferListRequest.  # noqa: E501

        The number of bank transfers to skip before returning results.  # noqa: E501

        :return: The offset of this BankTransferListRequest.  # noqa: E501
        :rtype: float
        """
        return self._offset

    @offset.setter
    def offset(self, offset):
        """Sets the offset of this BankTransferListRequest.

        The number of bank transfers to skip before returning results.  # noqa: E501

        :param offset: The offset of this BankTransferListRequest.  # noqa: E501
        :type offset: float
        """
        if (self.local_vars_configuration.client_side_validation and
                offset is not None and offset < 0):  # noqa: E501
            raise ValueError("Invalid value for `offset`, must be a value greater than or equal to `0`")  # noqa: E501

        self._offset = offset

    @property
    def origination_account_id(self):
        """Gets the origination_account_id of this BankTransferListRequest.  # noqa: E501

        Filter bank transfers to only those originated through the specified origination account.  # noqa: E501

        :return: The origination_account_id of this BankTransferListRequest.  # noqa: E501
        :rtype: str
        """
        return self._origination_account_id

    @origination_account_id.setter
    def origination_account_id(self, origination_account_id):
        """Sets the origination_account_id of this BankTransferListRequest.

        Filter bank transfers to only those originated through the specified origination account.  # noqa: E501

        :param origination_account_id: The origination_account_id of this BankTransferListRequest.  # noqa: E501
        :type origination_account_id: str
        """

        self._origination_account_id = origination_account_id

    @property
    def direction(self):
        """Gets the direction of this BankTransferListRequest.  # noqa: E501


        :return: The direction of this BankTransferListRequest.  # noqa: E501
        :rtype: BankTransferDirection
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this BankTransferListRequest.


        :param direction: The direction of this BankTransferListRequest.  # noqa: E501
        :type direction: BankTransferDirection
        """

        self._direction = direction

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BankTransferListRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BankTransferListRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class LiabilityOverride(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'purchase_apr': 'float',
        'cash_apr': 'float',
        'balance_transfer_apr': 'float',
        'special_apr': 'float',
        'last_payment_amount': 'float',
        'last_statement_balance': 'float',
        'minimum_payment_amount': 'float',
        'is_overdue': 'bool',
        'origination_date': 'str',
        'principal': 'float',
        'nominal_apr': 'float',
        'interest_capitalization_grace_period_months': 'float',
        'repayment_model': 'StudentLoanRepaymentModel',
        'expected_payoff_date': 'str',
        'guarantor': 'str',
        'is_federal': 'bool',
        'loan_name': 'str',
        'loan_status': 'str',
        'payment_reference_number': 'str',
        'pslf_status': 'str',
        'repayment_plan_description': 'str',
        'repayment_plan_type': 'str',
        'sequence_number': 'str',
        'servicer_address': 'Address'
    }

    attribute_map = {
        'type': 'type',
        'purchase_apr': 'purchase_apr',
        'cash_apr': 'cash_apr',
        'balance_transfer_apr': 'balance_transfer_apr',
        'special_apr': 'special_apr',
        'last_payment_amount': 'last_payment_amount',
        'last_statement_balance': 'last_statement_balance',
        'minimum_payment_amount': 'minimum_payment_amount',
        'is_overdue': 'is_overdue',
        'origination_date': 'origination_date',
        'principal': 'principal',
        'nominal_apr': 'nominal_apr',
        'interest_capitalization_grace_period_months': 'interest_capitalization_grace_period_months',
        'repayment_model': 'repayment_model',
        'expected_payoff_date': 'expected_payoff_date',
        'guarantor': 'guarantor',
        'is_federal': 'is_federal',
        'loan_name': 'loan_name',
        'loan_status': 'loan_status',
        'payment_reference_number': 'payment_reference_number',
        'pslf_status': 'pslf_status',
        'repayment_plan_description': 'repayment_plan_description',
        'repayment_plan_type': 'repayment_plan_type',
        'sequence_number': 'sequence_number',
        'servicer_address': 'servicer_address'
    }

    def __init__(self, type=None, purchase_apr=None, cash_apr=None, balance_transfer_apr=None, special_apr=None, last_payment_amount=None, last_statement_balance=None, minimum_payment_amount=None, is_overdue=None, origination_date=None, principal=None, nominal_apr=None, interest_capitalization_grace_period_months=None, repayment_model=None, expected_payoff_date=None, guarantor=None, is_federal=None, loan_name=None, loan_status=None, payment_reference_number=None, pslf_status=None, repayment_plan_description=None, repayment_plan_type=None, sequence_number=None, servicer_address=None, local_vars_configuration=None):  # noqa: E501
        """LiabilityOverride - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._purchase_apr = None
        self._cash_apr = None
        self._balance_transfer_apr = None
        self._special_apr = None
        self._last_payment_amount = None
        self._last_statement_balance = None
        self._minimum_payment_amount = None
        self._is_overdue = None
        self._origination_date = None
        self._principal = None
        self._nominal_apr = None
        self._interest_capitalization_grace_period_months = None
        self._repayment_model = None
        self._expected_payoff_date = None
        self._guarantor = None
        self._is_federal = None
        self._loan_name = None
        self._loan_status = None
        self._payment_reference_number = None
        self._pslf_status = None
        self._repayment_plan_description = None
        self._repayment_plan_type = None
        self._sequence_number = None
        self._servicer_address = None
        self.discriminator = None

        self.type = type
        if purchase_apr is not None:
            self.purchase_apr = purchase_apr
        if cash_apr is not None:
            self.cash_apr = cash_apr
        if balance_transfer_apr is not None:
            self.balance_transfer_apr = balance_transfer_apr
        if special_apr is not None:
            self.special_apr = special_apr
        if last_payment_amount is not None:
            self.last_payment_amount = last_payment_amount
        if last_statement_balance is not None:
            self.last_statement_balance = last_statement_balance
        if minimum_payment_amount is not None:
            self.minimum_payment_amount = minimum_payment_amount
        if is_overdue is not None:
            self.is_overdue = is_overdue
        if origination_date is not None:
            self.origination_date = origination_date
        if principal is not None:
            self.principal = principal
        if nominal_apr is not None:
            self.nominal_apr = nominal_apr
        if interest_capitalization_grace_period_months is not None:
            self.interest_capitalization_grace_period_months = interest_capitalization_grace_period_months
        if repayment_model is not None:
            self.repayment_model = repayment_model
        if expected_payoff_date is not None:
            self.expected_payoff_date = expected_payoff_date
        if guarantor is not None:
            self.guarantor = guarantor
        if is_federal is not None:
            self.is_federal = is_federal
        if loan_name is not None:
            self.loan_name = loan_name
        if loan_status is not None:
            self.loan_status = loan_status
        if payment_reference_number is not None:
            self.payment_reference_number = payment_reference_number
        if pslf_status is not None:
            self.pslf_status = pslf_status
        if repayment_plan_description is not None:
            self.repayment_plan_description = repayment_plan_description
        if repayment_plan_type is not None:
            self.repayment_plan_type = repayment_plan_type
        if sequence_number is not None:
            self.sequence_number = sequence_number
        if servicer_address is not None:
            self.servicer_address = servicer_address

    @property
    def type(self):
        """Gets the type of this LiabilityOverride.  # noqa: E501

        The type of the liability object, either `credit` or `student`.  # noqa: E501

        :return: The type of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LiabilityOverride.

        The type of the liability object, either `credit` or `student`.  # noqa: E501

        :param type: The type of this LiabilityOverride.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def purchase_apr(self):
        """Gets the purchase_apr of this LiabilityOverride.  # noqa: E501

        The purchase APR percentage value. For simplicity, this is the only interest rate used to calculate interest charges. Can only be set if `type` is `credit`.  # noqa: E501

        :return: The purchase_apr of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._purchase_apr

    @purchase_apr.setter
    def purchase_apr(self, purchase_apr):
        """Sets the purchase_apr of this LiabilityOverride.

        The purchase APR percentage value. For simplicity, this is the only interest rate used to calculate interest charges. Can only be set if `type` is `credit`.  # noqa: E501

        :param purchase_apr: The purchase_apr of this LiabilityOverride.  # noqa: E501
        :type purchase_apr: float
        """

        self._purchase_apr = purchase_apr

    @property
    def cash_apr(self):
        """Gets the cash_apr of this LiabilityOverride.  # noqa: E501

        The cash APR percentage value. Can only be set if `type` is `credit`.  # noqa: E501

        :return: The cash_apr of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._cash_apr

    @cash_apr.setter
    def cash_apr(self, cash_apr):
        """Sets the cash_apr of this LiabilityOverride.

        The cash APR percentage value. Can only be set if `type` is `credit`.  # noqa: E501

        :param cash_apr: The cash_apr of this LiabilityOverride.  # noqa: E501
        :type cash_apr: float
        """

        self._cash_apr = cash_apr

    @property
    def balance_transfer_apr(self):
        """Gets the balance_transfer_apr of this LiabilityOverride.  # noqa: E501

        The balance transfer APR percentage value. Can only be set if `type` is `credit`. Can only be set if `type` is `credit`.  # noqa: E501

        :return: The balance_transfer_apr of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._balance_transfer_apr

    @balance_transfer_apr.setter
    def balance_transfer_apr(self, balance_transfer_apr):
        """Sets the balance_transfer_apr of this LiabilityOverride.

        The balance transfer APR percentage value. Can only be set if `type` is `credit`. Can only be set if `type` is `credit`.  # noqa: E501

        :param balance_transfer_apr: The balance_transfer_apr of this LiabilityOverride.  # noqa: E501
        :type balance_transfer_apr: float
        """

        self._balance_transfer_apr = balance_transfer_apr

    @property
    def special_apr(self):
        """Gets the special_apr of this LiabilityOverride.  # noqa: E501

        The special APR percentage value. Can only be set if `type` is `credit`.  # noqa: E501

        :return: The special_apr of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._special_apr

    @special_apr.setter
    def special_apr(self, special_apr):
        """Sets the special_apr of this LiabilityOverride.

        The special APR percentage value. Can only be set if `type` is `credit`.  # noqa: E501

        :param special_apr: The special_apr of this LiabilityOverride.  # noqa: E501
        :type special_apr: float
        """

        self._special_apr = special_apr

    @property
    def last_payment_amount(self):
        """Gets the last_payment_amount of this LiabilityOverride.  # noqa: E501

        Override the `last_payment_amount` field. Can only be set if `type` is `credit`.  # noqa: E501

        :return: The last_payment_amount of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._last_payment_amount

    @last_payment_amount.setter
    def last_payment_amount(self, last_payment_amount):
        """Sets the last_payment_amount of this LiabilityOverride.

        Override the `last_payment_amount` field. Can only be set if `type` is `credit`.  # noqa: E501

        :param last_payment_amount: The last_payment_amount of this LiabilityOverride.  # noqa: E501
        :type last_payment_amount: float
        """

        self._last_payment_amount = last_payment_amount

    @property
    def last_statement_balance(self):
        """Gets the last_statement_balance of this LiabilityOverride.  # noqa: E501

        Override the `last_statement_balance` field. Can only be set if `type` is `credit`.  # noqa: E501

        :return: The last_statement_balance of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._last_statement_balance

    @last_statement_balance.setter
    def last_statement_balance(self, last_statement_balance):
        """Sets the last_statement_balance of this LiabilityOverride.

        Override the `last_statement_balance` field. Can only be set if `type` is `credit`.  # noqa: E501

        :param last_statement_balance: The last_statement_balance of this LiabilityOverride.  # noqa: E501
        :type last_statement_balance: float
        """

        self._last_statement_balance = last_statement_balance

    @property
    def minimum_payment_amount(self):
        """Gets the minimum_payment_amount of this LiabilityOverride.  # noqa: E501

        Override the `minimum_payment_amount` field. Can only be set if `type` is `credit`.  # noqa: E501

        :return: The minimum_payment_amount of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._minimum_payment_amount

    @minimum_payment_amount.setter
    def minimum_payment_amount(self, minimum_payment_amount):
        """Sets the minimum_payment_amount of this LiabilityOverride.

        Override the `minimum_payment_amount` field. Can only be set if `type` is `credit`.  # noqa: E501

        :param minimum_payment_amount: The minimum_payment_amount of this LiabilityOverride.  # noqa: E501
        :type minimum_payment_amount: float
        """

        self._minimum_payment_amount = minimum_payment_amount

    @property
    def is_overdue(self):
        """Gets the is_overdue of this LiabilityOverride.  # noqa: E501

        Override the `is_overdue` field  # noqa: E501

        :return: The is_overdue of this LiabilityOverride.  # noqa: E501
        :rtype: bool
        """
        return self._is_overdue

    @is_overdue.setter
    def is_overdue(self, is_overdue):
        """Sets the is_overdue of this LiabilityOverride.

        Override the `is_overdue` field  # noqa: E501

        :param is_overdue: The is_overdue of this LiabilityOverride.  # noqa: E501
        :type is_overdue: bool
        """

        self._is_overdue = is_overdue

    @property
    def origination_date(self):
        """Gets the origination_date of this LiabilityOverride.  # noqa: E501

        The date on which the loan was initially lent, in ISO 8601 (YYYY-MM-DD) format. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The origination_date of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._origination_date

    @origination_date.setter
    def origination_date(self, origination_date):
        """Sets the origination_date of this LiabilityOverride.

        The date on which the loan was initially lent, in ISO 8601 (YYYY-MM-DD) format. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param origination_date: The origination_date of this LiabilityOverride.  # noqa: E501
        :type origination_date: str
        """

        self._origination_date = origination_date

    @property
    def principal(self):
        """Gets the principal of this LiabilityOverride.  # noqa: E501

        The original loan principal. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The principal of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._principal

    @principal.setter
    def principal(self, principal):
        """Sets the principal of this LiabilityOverride.

        The original loan principal. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param principal: The principal of this LiabilityOverride.  # noqa: E501
        :type principal: float
        """

        self._principal = principal

    @property
    def nominal_apr(self):
        """Gets the nominal_apr of this LiabilityOverride.  # noqa: E501

        The interest rate on the loan as a percentage. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The nominal_apr of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._nominal_apr

    @nominal_apr.setter
    def nominal_apr(self, nominal_apr):
        """Sets the nominal_apr of this LiabilityOverride.

        The interest rate on the loan as a percentage. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param nominal_apr: The nominal_apr of this LiabilityOverride.  # noqa: E501
        :type nominal_apr: float
        """

        self._nominal_apr = nominal_apr

    @property
    def interest_capitalization_grace_period_months(self):
        """Gets the interest_capitalization_grace_period_months of this LiabilityOverride.  # noqa: E501

        If set, interest capitalization begins at the given number of months after loan origination. By default interest is never capitalized. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The interest_capitalization_grace_period_months of this LiabilityOverride.  # noqa: E501
        :rtype: float
        """
        return self._interest_capitalization_grace_period_months

    @interest_capitalization_grace_period_months.setter
    def interest_capitalization_grace_period_months(self, interest_capitalization_grace_period_months):
        """Sets the interest_capitalization_grace_period_months of this LiabilityOverride.

        If set, interest capitalization begins at the given number of months after loan origination. By default interest is never capitalized. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param interest_capitalization_grace_period_months: The interest_capitalization_grace_period_months of this LiabilityOverride.  # noqa: E501
        :type interest_capitalization_grace_period_months: float
        """

        self._interest_capitalization_grace_period_months = interest_capitalization_grace_period_months

    @property
    def repayment_model(self):
        """Gets the repayment_model of this LiabilityOverride.  # noqa: E501


        :return: The repayment_model of this LiabilityOverride.  # noqa: E501
        :rtype: StudentLoanRepaymentModel
        """
        return self._repayment_model

    @repayment_model.setter
    def repayment_model(self, repayment_model):
        """Sets the repayment_model of this LiabilityOverride.


        :param repayment_model: The repayment_model of this LiabilityOverride.  # noqa: E501
        :type repayment_model: StudentLoanRepaymentModel
        """

        self._repayment_model = repayment_model

    @property
    def expected_payoff_date(self):
        """Gets the expected_payoff_date of this LiabilityOverride.  # noqa: E501

        Override the `expected_payoff_date` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The expected_payoff_date of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._expected_payoff_date

    @expected_payoff_date.setter
    def expected_payoff_date(self, expected_payoff_date):
        """Sets the expected_payoff_date of this LiabilityOverride.

        Override the `expected_payoff_date` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param expected_payoff_date: The expected_payoff_date of this LiabilityOverride.  # noqa: E501
        :type expected_payoff_date: str
        """

        self._expected_payoff_date = expected_payoff_date

    @property
    def guarantor(self):
        """Gets the guarantor of this LiabilityOverride.  # noqa: E501

        Override the `guarantor` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The guarantor of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._guarantor

    @guarantor.setter
    def guarantor(self, guarantor):
        """Sets the guarantor of this LiabilityOverride.

        Override the `guarantor` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param guarantor: The guarantor of this LiabilityOverride.  # noqa: E501
        :type guarantor: str
        """

        self._guarantor = guarantor

    @property
    def is_federal(self):
        """Gets the is_federal of this LiabilityOverride.  # noqa: E501

        Override the `is_federal` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The is_federal of this LiabilityOverride.  # noqa: E501
        :rtype: bool
        """
        return self._is_federal

    @is_federal.setter
    def is_federal(self, is_federal):
        """Sets the is_federal of this LiabilityOverride.

        Override the `is_federal` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param is_federal: The is_federal of this LiabilityOverride.  # noqa: E501
        :type is_federal: bool
        """

        self._is_federal = is_federal

    @property
    def loan_name(self):
        """Gets the loan_name of this LiabilityOverride.  # noqa: E501

        Override the `loan_name` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The loan_name of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._loan_name

    @loan_name.setter
    def loan_name(self, loan_name):
        """Sets the loan_name of this LiabilityOverride.

        Override the `loan_name` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param loan_name: The loan_name of this LiabilityOverride.  # noqa: E501
        :type loan_name: str
        """

        self._loan_name = loan_name

    @property
    def loan_status(self):
        """Gets the loan_status of this LiabilityOverride.  # noqa: E501

        Override the `loan_status` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The loan_status of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._loan_status

    @loan_status.setter
    def loan_status(self, loan_status):
        """Sets the loan_status of this LiabilityOverride.

        Override the `loan_status` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param loan_status: The loan_status of this LiabilityOverride.  # noqa: E501
        :type loan_status: str
        """

        self._loan_status = loan_status

    @property
    def payment_reference_number(self):
        """Gets the payment_reference_number of this LiabilityOverride.  # noqa: E501

        Override the `payment_reference_number` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The payment_reference_number of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._payment_reference_number

    @payment_reference_number.setter
    def payment_reference_number(self, payment_reference_number):
        """Sets the payment_reference_number of this LiabilityOverride.

        Override the `payment_reference_number` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param payment_reference_number: The payment_reference_number of this LiabilityOverride.  # noqa: E501
        :type payment_reference_number: str
        """

        self._payment_reference_number = payment_reference_number

    @property
    def pslf_status(self):
        """Gets the pslf_status of this LiabilityOverride.  # noqa: E501

        Override the `pslf_status` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The pslf_status of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._pslf_status

    @pslf_status.setter
    def pslf_status(self, pslf_status):
        """Sets the pslf_status of this LiabilityOverride.

        Override the `pslf_status` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param pslf_status: The pslf_status of this LiabilityOverride.  # noqa: E501
        :type pslf_status: str
        """

        self._pslf_status = pslf_status

    @property
    def repayment_plan_description(self):
        """Gets the repayment_plan_description of this LiabilityOverride.  # noqa: E501

        Override the `repayment_plan.description` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The repayment_plan_description of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._repayment_plan_description

    @repayment_plan_description.setter
    def repayment_plan_description(self, repayment_plan_description):
        """Sets the repayment_plan_description of this LiabilityOverride.

        Override the `repayment_plan.description` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param repayment_plan_description: The repayment_plan_description of this LiabilityOverride.  # noqa: E501
        :type repayment_plan_description: str
        """

        self._repayment_plan_description = repayment_plan_description

    @property
    def repayment_plan_type(self):
        """Gets the repayment_plan_type of this LiabilityOverride.  # noqa: E501

        Override the `repayment_plan.type` field. Can only be set if `type` is `student_loan`. Possible values are: `\"extended graduated\"`, `\"extended standard\"`, `\"graduated\"`, `\"income-contingent repayment\"`, `\"income-based repayment\"`, `\"interest only\"`, `\"other\"`, `\"pay as you earn\"`, `\"revised pay as you earn\"`, or `\"standard\"`.  # noqa: E501

        :return: The repayment_plan_type of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._repayment_plan_type

    @repayment_plan_type.setter
    def repayment_plan_type(self, repayment_plan_type):
        """Sets the repayment_plan_type of this LiabilityOverride.

        Override the `repayment_plan.type` field. Can only be set if `type` is `student_loan`. Possible values are: `\"extended graduated\"`, `\"extended standard\"`, `\"graduated\"`, `\"income-contingent repayment\"`, `\"income-based repayment\"`, `\"interest only\"`, `\"other\"`, `\"pay as you earn\"`, `\"revised pay as you earn\"`, or `\"standard\"`.  # noqa: E501

        :param repayment_plan_type: The repayment_plan_type of this LiabilityOverride.  # noqa: E501
        :type repayment_plan_type: str
        """

        self._repayment_plan_type = repayment_plan_type

    @property
    def sequence_number(self):
        """Gets the sequence_number of this LiabilityOverride.  # noqa: E501

        Override the `sequence_number` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :return: The sequence_number of this LiabilityOverride.  # noqa: E501
        :rtype: str
        """
        return self._sequence_number

    @sequence_number.setter
    def sequence_number(self, sequence_number):
        """Sets the sequence_number of this LiabilityOverride.

        Override the `sequence_number` field. Can only be set if `type` is `student_loan`.  # noqa: E501

        :param sequence_number: The sequence_number of this LiabilityOverride.  # noqa: E501
        :type sequence_number: str
        """

        self._sequence_number = sequence_number

    @property
    def servicer_address(self):
        """Gets the servicer_address of this LiabilityOverride.  # noqa: E501


        :return: The servicer_address of this LiabilityOverride.  # noqa: E501
        :rtype: Address
        """
        return self._servicer_address

    @servicer_address.setter
    def servicer_address(self, servicer_address):
        """Sets the servicer_address of this LiabilityOverride.


        :param servicer_address: The servicer_address of this LiabilityOverride.  # noqa: E501
        :type servicer_address: Address
        """

        self._servicer_address = servicer_address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiabilityOverride):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LiabilityOverride):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class JWKPublicKey(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alg': 'str',
        'crv': 'str',
        'kid': 'str',
        'kty': 'str',
        'use': 'str',
        'x': 'str',
        'y': 'str'
    }

    attribute_map = {
        'alg': 'alg',
        'crv': 'crv',
        'kid': 'kid',
        'kty': 'kty',
        'use': 'use',
        'x': 'x',
        'y': 'y'
    }

    def __init__(self, alg=None, crv=None, kid=None, kty=None, use=None, x=None, y=None, local_vars_configuration=None):  # noqa: E501
        """JWKPublicKey - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alg = None
        self._crv = None
        self._kid = None
        self._kty = None
        self._use = None
        self._x = None
        self._y = None
        self.discriminator = None

        if alg is not None:
            self.alg = alg
        if crv is not None:
            self.crv = crv
        if kid is not None:
            self.kid = kid
        if kty is not None:
            self.kty = kty
        if use is not None:
            self.use = use
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y

    @property
    def alg(self):
        """Gets the alg of this JWKPublicKey.  # noqa: E501

        The alg member identifies the cryptographic algorithm family used with the key.  # noqa: E501

        :return: The alg of this JWKPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._alg

    @alg.setter
    def alg(self, alg):
        """Sets the alg of this JWKPublicKey.

        The alg member identifies the cryptographic algorithm family used with the key.  # noqa: E501

        :param alg: The alg of this JWKPublicKey.  # noqa: E501
        :type alg: str
        """

        self._alg = alg

    @property
    def crv(self):
        """Gets the crv of this JWKPublicKey.  # noqa: E501

        The crv member identifies the cryptographic curve used with the key.  # noqa: E501

        :return: The crv of this JWKPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._crv

    @crv.setter
    def crv(self, crv):
        """Sets the crv of this JWKPublicKey.

        The crv member identifies the cryptographic curve used with the key.  # noqa: E501

        :param crv: The crv of this JWKPublicKey.  # noqa: E501
        :type crv: str
        """

        self._crv = crv

    @property
    def kid(self):
        """Gets the kid of this JWKPublicKey.  # noqa: E501

        The kid (Key ID) member can be used to match a specific key. This can be used, for instance, to choose among a set of keys within the JWK during key rollover.  # noqa: E501

        :return: The kid of this JWKPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._kid

    @kid.setter
    def kid(self, kid):
        """Sets the kid of this JWKPublicKey.

        The kid (Key ID) member can be used to match a specific key. This can be used, for instance, to choose among a set of keys within the JWK during key rollover.  # noqa: E501

        :param kid: The kid of this JWKPublicKey.  # noqa: E501
        :type kid: str
        """

        self._kid = kid

    @property
    def kty(self):
        """Gets the kty of this JWKPublicKey.  # noqa: E501

        The kty (key type) parameter identifies the cryptographic algorithm family used with the key, such as RSA or EC.  # noqa: E501

        :return: The kty of this JWKPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._kty

    @kty.setter
    def kty(self, kty):
        """Sets the kty of this JWKPublicKey.

        The kty (key type) parameter identifies the cryptographic algorithm family used with the key, such as RSA or EC.  # noqa: E501

        :param kty: The kty of this JWKPublicKey.  # noqa: E501
        :type kty: str
        """

        self._kty = kty

    @property
    def use(self):
        """Gets the use of this JWKPublicKey.  # noqa: E501

        The use (public key use) parameter identifies the intended use of the public key.  # noqa: E501

        :return: The use of this JWKPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._use

    @use.setter
    def use(self, use):
        """Sets the use of this JWKPublicKey.

        The use (public key use) parameter identifies the intended use of the public key.  # noqa: E501

        :param use: The use of this JWKPublicKey.  # noqa: E501
        :type use: str
        """

        self._use = use

    @property
    def x(self):
        """Gets the x of this JWKPublicKey.  # noqa: E501

        The x member contains the x coordinate for the elliptic curve point.  # noqa: E501

        :return: The x of this JWKPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this JWKPublicKey.

        The x member contains the x coordinate for the elliptic curve point.  # noqa: E501

        :param x: The x of this JWKPublicKey.  # noqa: E501
        :type x: str
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this JWKPublicKey.  # noqa: E501

        The y member contains the y coordinate for the elliptic curve point.  # noqa: E501

        :return: The y of this JWKPublicKey.  # noqa: E501
        :rtype: str
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this JWKPublicKey.

        The y member contains the y coordinate for the elliptic curve point.  # noqa: E501

        :param y: The y of this JWKPublicKey.  # noqa: E501
        :type y: str
        """

        self._y = y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JWKPublicKey):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, JWKPublicKey):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AssetReportAuditCopyRemoveRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'client_id': 'str',
        'secret': 'str',
        'audit_copy_token': 'str'
    }

    attribute_map = {
        'client_id': 'client_id',
        'secret': 'secret',
        'audit_copy_token': 'audit_copy_token'
    }

    def __init__(self, client_id=None, secret=None, audit_copy_token=None, local_vars_configuration=None):  # noqa: E501
        """AssetReportAuditCopyRemoveRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_id = None
        self._secret = None
        self._audit_copy_token = None
        self.discriminator = None

        self.client_id = client_id
        self.secret = secret
        self.audit_copy_token = audit_copy_token

    @property
    def client_id(self):
        """Gets the client_id of this AssetReportAuditCopyRemoveRequest.  # noqa: E501

        Your Plaid API `client_id`.  # noqa: E501

        :return: The client_id of this AssetReportAuditCopyRemoveRequest.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this AssetReportAuditCopyRemoveRequest.

        Your Plaid API `client_id`.  # noqa: E501

        :param client_id: The client_id of this AssetReportAuditCopyRemoveRequest.  # noqa: E501
        :type client_id: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501

        self._client_id = client_id

    @property
    def secret(self):
        """Gets the secret of this AssetReportAuditCopyRemoveRequest.  # noqa: E501

        Your Plaid API `secret`.  # noqa: E501

        :return: The secret of this AssetReportAuditCopyRemoveRequest.  # noqa: E501
        :rtype: str
        """
        return self._secret

    @secret.setter
    def secret(self, secret):
        """Sets the secret of this AssetReportAuditCopyRemoveRequest.

        Your Plaid API `secret`.  # noqa: E501

        :param secret: The secret of this AssetReportAuditCopyRemoveRequest.  # noqa: E501
        :type secret: str
        """
        if self.local_vars_configuration.client_side_validation and secret is None:  # noqa: E501
            raise ValueError("Invalid value for `secret`, must not be `None`")  # noqa: E501

        self._secret = secret

    @property
    def audit_copy_token(self):
        """Gets the audit_copy_token of this AssetReportAuditCopyRemoveRequest.  # noqa: E501

        The `audit_copy_token` granting access to the Audit Copy you would like to revoke.  # noqa: E501

        :return: The audit_copy_token of this AssetReportAuditCopyRemoveRequest.  # noqa: E501
        :rtype: str
        """
        return self._audit_copy_token

    @audit_copy_token.setter
    def audit_copy_token(self, audit_copy_token):
        """Sets the audit_copy_token of this AssetReportAuditCopyRemoveRequest.

        The `audit_copy_token` granting access to the Audit Copy you would like to revoke.  # noqa: E501

        :param audit_copy_token: The audit_copy_token of this AssetReportAuditCopyRemoveRequest.  # noqa: E501
        :type audit_copy_token: str
        """
        if self.local_vars_configuration.client_side_validation and audit_copy_token is None:  # noqa: E501
            raise ValueError("Invalid value for `audit_copy_token`, must not be `None`")  # noqa: E501

        self._audit_copy_token = audit_copy_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetReportAuditCopyRemoveRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetReportAuditCopyRemoveRequest):
            return True

        return self.to_dict() != other.to_dict()
